@@ -1,17 +1,21 @@
 /*
- * BeerXMLElement.h is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * BeerXMLElement.h is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Jeff Bailey <skydvr38@verizon.net>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -57,9 +61,10 @@ public:
    BeerXMLElement();
    BeerXMLElement( BeerXMLElement const& other );
 
-   // Everything that inherits from BeerXML has a delete and a display
+   // Everything that inherits from BeerXML has delete, display and a folder
    Q_PROPERTY( bool deleted READ deleted WRITE setDeleted )
    Q_PROPERTY( bool display READ display WRITE setDisplay )
+   Q_PROPERTY( QString folder READ folder WRITE setFolder )
 
    Q_PROPERTY( int key READ key )
    Q_PROPERTY( Brewtarget::DBTable table READ table )
@@ -67,9 +72,14 @@ public:
    //! Convenience method to determine if we are deleted or displayed
    bool deleted() const;
    bool display() const;
+   //! Access to the folder attribute.
+   QString folder() const;
+
    //! And ways to set those flags
    void setDeleted(bool var);
    void setDisplay(bool var);
+   //! and a way to set the folder
+   virtual void setFolder(QString var, bool signal=true);
 
    //! \returns our key in the table we are stored in.
    int key() const;
@@ -121,6 +131,7 @@ signals:
     * the same signature. Otherwise, everything will silently break.
     */
    void changed(QMetaProperty, QVariant value = QVariant());
+   void changedFolder(QString);
    
 protected:
    
@@ -130,11 +141,13 @@ protected:
    Brewtarget::DBTable _table;
 
    /*!
-    * \param prop_name - A meta-property name
-    * \param col_name - The appropriate column in the table.
+    * \param prop_name A meta-property name
+    * \param col_name The appropriate column in the table.
+    * \param value the new value
+    * \param notify true to call NOTIFY method associated with \c prop_name
     * Should do the following:
     * 1) Set the appropriate value in the appropriate table row.
-    * 2) Call the NOTIFY method associated with \b prop_name if \b notify == true.
+    * 2) Call the NOTIFY method associated with \c prop_name if \c notify == true.
     */
    void set( const char* prop_name, const char* col_name, QVariant const& value, bool notify = true );
    
@@ -144,6 +157,11 @@ protected:
     */
    QVariant get( const char* col_name ) const;
    
+   void setInventory( const char* prop_name, const char* col_name, QVariant const& value, bool notify = true );
+   QVariant getInventory( const char* col_name ) const;
+   
+   
+   
 private:
    /*!
     * \param valid - Indicates if the beerXML element was valid. There is a problem with importing invalid
