@@ -1,17 +1,20 @@
 /*
- * BrewDayWidget.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * BrewDayWidget.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -178,13 +181,13 @@ QString BrewDayWidget::buildTitleTable()
            .arg(tr("Boil Volume"))
            .arg(Brewtarget::displayAmount(recObs->boilSize_l(),Units::liters,2))
            .arg(tr("Preboil Gravity"))
-           .arg(Brewtarget::displayOG(recObs->boilGrav()));
+           .arg(Brewtarget::displayAmount(recObs->boilGrav(), Units::sp_grav, 3));
 
    body += QString("<tr><td class=\"left\">%1</td><td class=\"value\">%2</td><td class=\"right\">%3</td><td class=\"value\">%4</td></tr>")
            .arg(tr("Final Volume"))
            .arg(Brewtarget::displayAmount(recObs->batchSize_l(), Units::liters,2))
            .arg(tr("Starting Gravity"))
-           .arg(Brewtarget::displayOG(recObs->og()));
+           .arg(Brewtarget::displayAmount(recObs->og(), Units::sp_grav, 3));
 
    body += QString("<tr><td class=\"left\">%1</td><td class=\"value\">%2</td><td class=\"right\">%3</td><td class=\"value\">%4</td></tr>")
            .arg(tr("Boil Time"))
@@ -195,8 +198,8 @@ QString BrewDayWidget::buildTitleTable()
    body += QString("<tr><td class=\"left\">%1</td><td class=\"value\">%2</td><td class=\"right\">%3</td><td class=\"value\">%4</tr>")
            .arg(tr("Predicted Efficiency"))
            .arg(Brewtarget::displayAmount(recObs->efficiency_pct(),0,0))
-           .arg(tr("Estimated calories (per 12 oz)"))
-           .arg(Brewtarget::displayAmount(recObs->calories(),0,0));
+           .arg(Brewtarget::getVolumeUnitSystem() == SI ? tr("Estimated calories (per 33 cl)") : tr("Estimated calories (per 12 oz)"))
+           .arg(Brewtarget::displayAmount(Brewtarget::getVolumeUnitSystem() == SI ? recObs->calories33cl() : recObs->calories12oz(),0,0));
 
    body += "</table>";
 
@@ -356,7 +359,7 @@ void BrewDayWidget::clear()
    {
       InstructionWidget* iw = (InstructionWidget*)stackedWidget->widget(0);
       stackedWidget->removeWidget(iw);
-			iw->deleteLater();
+         iw->deleteLater();
    }
 
    stackedWidget->setCurrentIndex(0);
