@@ -1,22 +1,24 @@
 /*
- * BtDigitWidget.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2010-2013.
+ * BtDigitWidget.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "BtDigitWidget.h"
+#include "brewtarget.h"
 #include <QFrame>
 #include <iostream>
 #include <QLocale>
@@ -44,13 +46,17 @@ BtDigitWidget::BtDigitWidget(QWidget *parent) : QLabel(parent)
 void BtDigitWidget::display(QString str)
 {
    static bool converted;
-   
-   lastNum = str.toDouble(&converted);
+  
+
+   lastNum = Brewtarget::toDouble(str,&converted);
    lastPrec = str.length() - str.lastIndexOf(QLocale().decimalPoint()) - 1;
    if( converted )
       display(lastNum,lastPrec);
    else
+   {
+      Brewtarget::logW( QString( "BtDigitWidget::display(QString) could not convert %1 to double").arg(str));
       setText("-");
+   }
 }
 
 void BtDigitWidget::display(double num, int prec)
