@@ -1,17 +1,21 @@
 /*
- * FermentableTableModel.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * FermentableTableModel.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
+ * - swstim <swstim@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -19,10 +23,10 @@
 #include <QAbstractTableModel>
 #include <QAbstractItemModel>
 #include <QAbstractItemView>
+#include <QHeaderView>
 #include <QWidget>
 #include <QModelIndex>
 #include <QVariant>
-#include <QCheckBox>
 #include <QItemEditorFactory>
 #include <QStyle>
 #include <QRect>
@@ -32,9 +36,11 @@
 #include "brewtarget.h"
 #include <QSize>
 #include <QComboBox>
+#include <QListWidget>
 #include <QLineEdit>
 #include <QString>
 #include <QVector>
+#include <QHeaderView>
 #include "fermentable.h"
 #include "FermentableTableModel.h"
 #include "unit.h"
@@ -42,16 +48,25 @@
 
 //=====================CLASS FermentableTableModel==============================
 FermentableTableModel::FermentableTableModel(QTableView* parent, bool editable)
-   : QAbstractTableModel(parent), 
-     parentTableWidget(parent), 
-     editable(editable), 
-     recObs(0), 
-     displayPercentages(false), 
+   : QAbstractTableModel(parent),
+     parentTableWidget(parent),
+     editable(editable),
+     _inventoryEditable(false),
+     recObs(0),
+     displayPercentages(false),
      totalFermMass_kg(0)
 {
    fermObs.clear();
    // for units and scales
-   setObjectName("fermentableTable"); 
+   setObjectName("fermentableTable");
+
+   // Will this work here? Yes. Yes it will. Bwahahahahahaha
+   QHeaderView* headerView = parentTableWidget->horizontalHeader();
+   headerView->setContextMenuPolicy(Qt::CustomContextMenu);
+   parentTableWidget->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->setWordWrap(false);
+   connect(headerView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(contextMenu(const QPoint&)));
 }
 
 void FermentableTableModel::observeRecipe(Recipe* rec)
@@ -61,7 +76,7 @@ void FermentableTableModel::observeRecipe(Recipe* rec)
       disconnect( recObs, 0, this, 0 );
       removeAll();
    }
-   
+
    recObs = rec;
    if( recObs )
    {
@@ -76,7 +91,7 @@ void FermentableTableModel::observeDatabase(bool val)
    {
       // Observing a database and a recipe are mutually exclusive.
       observeRecipe(0);
-      
+
       removeAll();
       connect( &(Database::instance()), SIGNAL(newFermentableSignal(Fermentable*)), this, SLOT(addFermentable(Fermentable*)) );
       connect( &(Database::instance()), SIGNAL(deletedFermentableSignal(Fermentable*)), this, SLOT(removeFermentable(Fermentable*)) );
@@ -104,7 +119,7 @@ void FermentableTableModel::addFermentable(Fermentable* ferm)
       )
    )
       return;
- 
+
    int size = fermObs.size();
    beginInsertRows( QModelIndex(), size, size );
    fermObs.append(ferm);
@@ -112,71 +127,53 @@ void FermentableTableModel::addFermentable(Fermentable* ferm)
    totalFermMass_kg += ferm->amount_kg();
    //reset(); // Tell everybody that the table has changed.
    endInsertRows();
-   
-   if(parentTableWidget)
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
 }
 
 void FermentableTableModel::addFermentables(QList<Fermentable*> ferms)
 {
    QList<Fermentable*>::iterator i;
    QList<Fermentable*> tmp;
-   
+
    for( i = ferms.begin(); i != ferms.end(); i++ )
    {
       if( !fermObs.contains(*i) )
          tmp.append(*i);
    }
-   
+
    int size = fermObs.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       fermObs.append(tmp);
-   
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
       {
          connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
          totalFermMass_kg += (*i)->amount_kg();
       }
-   
+
       endInsertRows();
    }
-   
-   if(parentTableWidget)
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
 }
 
 bool FermentableTableModel::removeFermentable(Fermentable* ferm)
 {
    int i;
-   
+
    i = fermObs.indexOf(ferm);
    if( i >= 0 )
    {
       beginRemoveRows( QModelIndex(), i, i );
       disconnect( ferm, 0, this, 0 );
       fermObs.removeAt(i);
-      
+
       totalFermMass_kg -= ferm->amount_kg();
       //reset(); // Tell everybody the table has changed.
       endRemoveRows();
-      
-      if(parentTableWidget)
-      {
-         parentTableWidget->resizeColumnsToContents();
-         parentTableWidget->resizeRowsToContents();
-      }
-         
+
       return true;
    }
-      
+
    return false;
 }
 
@@ -198,9 +195,9 @@ void FermentableTableModel::removeAll()
 void FermentableTableModel::updateTotalGrains()
 {
    int i, size;
-   
+
    totalFermMass_kg = 0;
-   
+
    size = fermObs.size();
    for( i = 0; i < size; ++i )
       totalFermMass_kg += fermObs[i]->amount_kg();
@@ -214,7 +211,7 @@ void FermentableTableModel::setDisplayPercentages(bool var)
 void FermentableTableModel::changed(QMetaProperty prop, QVariant /*val*/)
 {
    int i;
-   
+
    // Is sender one of our fermentables?
    Fermentable* fermSender = qobject_cast<Fermentable*>(sender());
    if( fermSender )
@@ -222,7 +219,7 @@ void FermentableTableModel::changed(QMetaProperty prop, QVariant /*val*/)
       i = fermObs.indexOf(fermSender);
       if( i < 0 )
          return;
-      
+
       updateTotalGrains();
       emit dataChanged( QAbstractItemModel::createIndex(i, 0),
                         QAbstractItemModel::createIndex(i, FERMNUMCOLS-1));
@@ -231,7 +228,7 @@ void FermentableTableModel::changed(QMetaProperty prop, QVariant /*val*/)
       //reset();
       return;
    }
-   
+
    // See if our recipe gained or lost fermentables.
    Recipe* recSender = qobject_cast<Recipe*>(sender());
    if( recSender && recSender == recObs && QString(prop.name()) == "fermentables" )
@@ -256,18 +253,18 @@ QVariant FermentableTableModel::data( const QModelIndex& index, int role ) const
 {
    Fermentable* row;
    int col = index.column();
-   unitScale scale;
-   unitDisplay unit;
-   
+   Unit::unitScale scale;
+   Unit::unitDisplay unit;
+
    // Ensure the row is ok.
    if( index.row() >= (int)fermObs.size() )
    {
-      Brewtarget::log(Brewtarget::ERROR, tr("Bad model index. row = %1").arg(index.row()));
+      Brewtarget::logE(tr("Bad model index. row = %1").arg(index.row()));
       return QVariant();
    }
    else
       row = fermObs[index.row()];
-   
+
    switch( col )
    {
       case FERMNAMECOL:
@@ -282,36 +279,36 @@ QVariant FermentableTableModel::data( const QModelIndex& index, int role ) const
             return QVariant(row->type());
          else
             return QVariant();
+      case FERMINVENTORYCOL:
+         if( role != Qt::DisplayRole )
+            return QVariant();
+
+         // So just query the columns
+         unit  = displayUnit(col);
+         scale = displayScale(col);
+
+         return QVariant( Brewtarget::displayAmount(row->inventory(), Units::kilograms, 3, unit, scale) );
       case FERMAMOUNTCOL:
          if( role != Qt::DisplayRole )
             return QVariant();
 
-         // Figure out which unit to use. The cell-specific code is on hold
-         // unit  = row->displayUnit()  == noUnit ? displayUnit(col)  : row->displayUnit(); 
-         // scale = row->displayScale() == noScale ? displayScale(col) : row->displayScale(); 
-         
          // So just query the columns
          unit  = displayUnit(col);
-         scale = displayScale(col); 
+         scale = displayScale(col);
 
          return QVariant( Brewtarget::displayAmount(row->amount_kg(), Units::kilograms, 3, unit, scale) );
       case FERMISMASHEDCOL:
-         if( role == Qt::CheckStateRole )
-            return QVariant( row->isMashed() ? Qt::Checked : Qt::Unchecked);
-         else if( role == Qt::DisplayRole )
-         {
-            if( row->type() == Fermentable::Grain)
-               return row->isMashed() ? tr("Mashed") : tr("Steeped");
-            else
-               return row->isMashed() ? tr("Mashed") : tr("Not mashed");
-         }
+         if( role == Qt::DisplayRole )
+            return QVariant(row->additionMethodStringTr());
+         else if( role == Qt::UserRole )
+            return QVariant(row->additionMethod());
          else
             return QVariant();
       case FERMAFTERBOIL:
-         if( role == Qt::CheckStateRole )
-            return QVariant( row->addAfterBoil() ? Qt::Checked : Qt::Unchecked );
-         else if( role == Qt::DisplayRole )
-            return row->addAfterBoil()? tr("Late") : tr("Normal");
+         if( role == Qt::DisplayRole )
+            return QVariant(row->additionTimeStringTr());
+         else if( role == Qt::UserRole )
+            return QVariant(row->additionTime());
          else
             return QVariant();
       case FERMYIELDCOL:
@@ -324,19 +321,17 @@ QVariant FermentableTableModel::data( const QModelIndex& index, int role ) const
             return QVariant();
 
          unit  = displayUnit(col);
-         if ( unit == noUnit )
-            unit = Brewtarget::getColorUnit();
 
-         return QVariant( Brewtarget::displayColor(row->color_srm(), unit, false) );
+         return QVariant( Brewtarget::displayAmount(row->color_srm(), Units::srm, 0, unit) );
       default :
-         Brewtarget::log(Brewtarget::ERROR, tr("Bad column: %1").arg(col));
+         Brewtarget::logE(tr("Bad column: %1").arg(col));
          return QVariant();
    }
 }
 
 QVariant FermentableTableModel::headerData( int section, Qt::Orientation orientation, int role ) const
 {
-   int unit;
+   QString uName;
    if( orientation == Qt::Horizontal && role == Qt::DisplayRole )
    {
       switch( section )
@@ -345,25 +340,20 @@ QVariant FermentableTableModel::headerData( int section, Qt::Orientation orienta
             return QVariant(tr("Name"));
          case FERMTYPECOL:
             return QVariant(tr("Type"));
+         case FERMINVENTORYCOL:
+            return QVariant(tr("Inventory"));
          case FERMAMOUNTCOL:
             return QVariant(tr("Amount"));
          case FERMISMASHEDCOL:
-            return QVariant(tr("Mashed"));
+            return QVariant(tr("Method"));
          case FERMAFTERBOIL:
-            return QVariant(tr("Late Addition"));
+            return QVariant(tr("Addition"));
          case FERMYIELDCOL:
             return QVariant(tr("Yield %"));
          case FERMCOLORCOL:
-            unit = displayUnit(section);
-            if ( unit == noUnit )
-               unit = Brewtarget::getColorUnit();
-
-            if ( unit == displaySrm)
-               return QVariant(tr("Color (SRM)"));
-            else
-               return QVariant(tr("Color (EBC)"));
+            return QVariant(tr("Color"));
          default:
-            Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(section));
+            Brewtarget::logW(tr("Bad column: %1").arg(section));
             return QVariant();
       }
    }
@@ -374,8 +364,8 @@ QVariant FermentableTableModel::headerData( int section, Qt::Orientation orienta
          perMass = fermObs[section]->amount_kg()/totalFermMass_kg;
       return QVariant( QString("%1%").arg( (double)100.0 * perMass, 0, 'f', 0 ) );
    }
-   else
-      return QVariant();
+
+   return QVariant();
 }
 
 Qt::ItemFlags FermentableTableModel::flags(const QModelIndex& index ) const
@@ -383,45 +373,50 @@ Qt::ItemFlags FermentableTableModel::flags(const QModelIndex& index ) const
    Qt::ItemFlags defaults = Qt::ItemIsEnabled;
    int col = index.column();
    Fermentable* row = fermObs[index.row()];
-   
-   if( col == FERMISMASHEDCOL )
+
+   switch(col)
    {
-      // Ensure that being mashed and being a late addition are mutually exclusive.
-      if( !row->addAfterBoil() )
-         return (defaults | (editable ? Qt::ItemIsUserCheckable : Qt::NoItemFlags));
-      else
-         return (editable ? Qt::ItemIsUserCheckable : Qt::NoItemFlags);
+      case FERMISMASHEDCOL:
+         // Ensure that being mashed and being a late addition are mutually exclusive.
+         if( !row->addAfterBoil() )
+            return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled);
+         else
+            return Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled;
+         break;
+      case FERMAFTERBOIL:
+         // Ensure that being mashed and being a late addition are mutually exclusive.
+         if( !row->isMashed() )
+            return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled);
+         else
+            return Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled;
+         break;
+      case FERMNAMECOL:
+         return (defaults | Qt::ItemIsSelectable);
+         break;
+      case FERMINVENTORYCOL:
+         return (defaults | (_inventoryEditable ? Qt::ItemIsEditable : Qt::NoItemFlags));
+         break;
+      default:
+         return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) );
    }
-   else if( col == FERMAFTERBOIL )
-   {
-      // Ensure that being mashed and being a late addition are mutually exclusive.
-      if( !row->isMashed() )
-         return (defaults | (editable ? Qt::ItemIsUserCheckable : Qt::NoItemFlags));
-      else
-         return (editable ? Qt::ItemIsUserCheckable : Qt::NoItemFlags);
-   }
-   else if(  col == FERMNAMECOL )
-      return (defaults | Qt::ItemIsSelectable);
-   else
-      return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) );
 }
 
 /* --maf--
    The cell-specific work has been momentarily disabled until I can find a
    better way to implement. PLEASE DO NOT DELETE
-unitDisplay FermentableTableModel::displayUnit(const QModelIndex& index)
+Unit::unitDisplay FermentableTableModel::displayUnit(const QModelIndex& index)
 {
    Fermentable* row;
 
    if ( index.row() >= fermObs.size() )
-      return noUnit;
+      return Unit::noUnit;
 
    row = fermObs[index.row()];
 
    return row->displayUnit();
 }
 
-void FermentableTableModel::setDisplayUnit(const QModelIndex& index, unitDisplay displayUnit)
+void FermentableTableModel::setDisplayUnit(const QModelIndex& index, Unit::unitDisplay displayUnit)
 {
    Fermentable* row;
 
@@ -432,19 +427,19 @@ void FermentableTableModel::setDisplayUnit(const QModelIndex& index, unitDisplay
    row->setDisplayUnit(displayUnit);
 }
 
-unitScale FermentableTableModel::displayScale(const QModelIndex& index)
+Unit::unitScale FermentableTableModel::displayScale(const QModelIndex& index)
 {
    Fermentable* row;
 
    if ( index.row() >= fermObs.size() )
-      return noScale;
+      return Unit::noScale;
 
    row = fermObs[index.row()];
 
    return row->displayScale();
 }
 
-void FermentableTableModel::setDisplayScale(const QModelIndex& index, unitScale displayScale)
+void FermentableTableModel::setDisplayScale(const QModelIndex& index, Unit::unitScale displayScale)
 {
    Fermentable* row;
 
@@ -456,31 +451,31 @@ void FermentableTableModel::setDisplayScale(const QModelIndex& index, unitScale
 }
 */
 
-unitDisplay FermentableTableModel::displayUnit(int column) const
-{ 
+Unit::unitDisplay FermentableTableModel::displayUnit(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noUnit;
+      return Unit::noUnit;
 
-   return (unitDisplay)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::UNIT).toInt();
+   return (Unit::unitDisplay)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::UNIT).toInt();
 }
 
-unitScale FermentableTableModel::displayScale(int column) const
-{ 
+Unit::unitScale FermentableTableModel::displayScale(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noScale;
+      return Unit::noScale;
 
-   return (unitScale)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::SCALE).toInt();
+   return (Unit::unitScale)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::SCALE).toInt();
 }
 
 // We need to:
 //   o clear the custom scale if set
 //   o clear any custom unit from the rows
 //      o which should have the side effect of clearing any scale
-void FermentableTableModel::setDisplayUnit(int column, unitDisplay displayUnit) 
+void FermentableTableModel::setDisplayUnit(int column, Unit::unitDisplay displayUnit)
 {
    // Fermentable* row; // disabled per-cell magic
    QString attribute = generateName(column);
@@ -488,21 +483,21 @@ void FermentableTableModel::setDisplayUnit(int column, unitDisplay displayUnit)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayUnit,this,Brewtarget::UNIT); 
-   Brewtarget::setOption(attribute,noScale,this,Brewtarget::SCALE);
+   Brewtarget::setOption(attribute,displayUnit,this->objectName(),Brewtarget::UNIT);
+   Brewtarget::setOption(attribute,Unit::noScale,this->objectName(),Brewtarget::SCALE);
 
    /* Disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getFermentable(i);
-      row->setDisplayUnit(noUnit);
+      row->setDisplayUnit(Unit::noUnit);
    }
    */
 }
 
 // Setting the scale should clear any cell-level scaling options
-void FermentableTableModel::setDisplayScale(int column, unitScale displayScale) 
-{ 
+void FermentableTableModel::setDisplayScale(int column, Unit::unitScale displayScale)
+{
    // Fermentable* row; //disabled per-cell magic
 
    QString attribute = generateName(column);
@@ -510,13 +505,13 @@ void FermentableTableModel::setDisplayScale(int column, unitScale displayScale)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayScale,this,Brewtarget::SCALE); 
+   Brewtarget::setOption(attribute,displayScale,this->objectName(),Brewtarget::SCALE);
 
    /* disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getFermentable(i);
-      row->setDisplayScale(noScale);
+      row->setDisplayScale(Unit::noScale);
    }
    */
 }
@@ -527,6 +522,9 @@ QString FermentableTableModel::generateName(int column) const
 
    switch(column)
    {
+      case FERMINVENTORYCOL:
+         attribute = "inventory_kg";
+         break;
       case FERMAMOUNTCOL:
          attribute = "amount_kg";
          break;
@@ -539,91 +537,112 @@ QString FermentableTableModel::generateName(int column) const
    return attribute;
 }
 
+// oofrab
+void FermentableTableModel::contextMenu(const QPoint &point)
+{
+   QObject* calledBy = sender();
+   QHeaderView* hView = qobject_cast<QHeaderView*>(calledBy);
+
+   int selected = hView->logicalIndexAt(point);
+   Unit::unitDisplay currentUnit;
+   Unit::unitScale  currentScale;
+
+   // Since we need to call setupMassMenu() two different ways, we need
+   // to figure out the currentUnit and Scale here
+   currentUnit  = displayUnit(selected);
+   currentScale = displayScale(selected);
+
+   QMenu* menu;
+   QAction* invoked;
+
+   switch(selected)
+   {
+      case FERMINVENTORYCOL:
+      case FERMAMOUNTCOL:
+         menu = Brewtarget::setupMassMenu(parentTableWidget,currentUnit, currentScale);
+         break;
+      case FERMCOLORCOL:
+         menu = Brewtarget::setupColorMenu(parentTableWidget,currentUnit);
+         break;
+      default:
+         return;
+   }
+
+   invoked = menu->exec(hView->mapToGlobal(point));
+   if ( invoked == 0 )
+      return;
+
+   QWidget* pMenu = invoked->parentWidget();
+   if ( pMenu == menu )
+      setDisplayUnit(selected,(Unit::unitDisplay)invoked->data().toInt());
+   else
+      setDisplayScale(selected,(Unit::unitScale)invoked->data().toInt());
+
+}
+
 bool FermentableTableModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
    Fermentable* row;
-   double color;
-   unitDisplay unit;
-   
+   bool retVal = false;
+
    if( index.row() >= (int)fermObs.size() )
    {
       return false;
    }
    else
       row = fermObs[index.row()];
-   
+
    switch( index.column() )
    {
       case FERMNAMECOL:
-         if( value.canConvert(QVariant::String))
-         {
+         retVal = value.canConvert(QVariant::String);
+         if ( retVal )
             row->setName(value.toString());
-            return true;
-         }
-         else
-            return false;
+         break;
       case FERMTYPECOL:
-         if( value.canConvert(QVariant::Int) )
-         {
+         retVal = value.canConvert(QVariant::Int);
+         if ( retVal )
             row->setType( static_cast<Fermentable::Type>(value.toInt()));
-            return true;
-         }
-         else
-            return false;
+         break;
+      case FERMINVENTORYCOL:
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
+            row->setInventoryAmount( Brewtarget::qStringToSI(value.toString(), Units::kilograms,displayUnit(FERMINVENTORYCOL)));
+         break;
       case FERMAMOUNTCOL:
-         if( value.canConvert(QVariant::String) )
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
          {
-            row->setAmount_kg( Brewtarget::weightQStringToSI(value.toString(),displayUnit(FERMAMOUNTCOL)));
+            row->setAmount_kg( Brewtarget::qStringToSI(value.toString(), Units::kilograms,displayUnit(FERMAMOUNTCOL)));
             if( rowCount() > 0 )
                headerDataChanged( Qt::Vertical, 0, rowCount()-1 ); // Need to re-show header (grain percent).
-            return true;
          }
-         else
-            return false;
+         break;
       case FERMISMASHEDCOL:
-         if( role == Qt::CheckStateRole && value.canConvert(QVariant::Int) )
-         {
-            row->setIsMashed( ((Qt::CheckState)value.toInt()) == Qt::Checked );
-            return true;
-         }
-         else
-            return false;
+         retVal = value.canConvert(QVariant::Int);
+         if( retVal )
+            row->setAdditionMethod(static_cast<Fermentable::AdditionMethod>(value.toInt()));
+         break;
       case FERMAFTERBOIL:
-         if( role == Qt::CheckStateRole && value.canConvert(QVariant::Int) )
-         {
-            row->setAddAfterBoil( ((Qt::CheckState)value.toInt()) == Qt::Checked );
-            return true;
-         }
-         else
-            return false;
+         retVal = value.canConvert(QVariant::Int);
+         if( retVal )
+            row->setAdditionTime(static_cast<Fermentable::AdditionTime>(value.toInt()));
+         break;
       case FERMYIELDCOL:
-         if( value.canConvert(QVariant::Double) )
-         {
+         retVal = value.canConvert(QVariant::Double);
+         if( retVal )
             row->setYield_pct( value.toDouble() );
-            return true;
-         }
-         else
-            return false;
+         break;
       case FERMCOLORCOL:
-         if( value.canConvert(QVariant::Double) )
-         {
-            unit = displayUnit(index.column());
-            if ( unit == noUnit )
-               unit = Brewtarget::getColorUnit();
-
-            color = value.toDouble();
-            if ( unit == displayEbc )
-               color = Units::ebc->toSI(value.toDouble());
-
-            row->setColor_srm( color );
-            return true;
-         }
-         else
-            return false;
+         retVal = value.canConvert(QVariant::Double);
+         if( retVal )
+            row->setColor_srm(Brewtarget::qStringToSI(value.toString(), Units::srm, displayUnit(FERMCOLORCOL)));
+         break;
       default:
-         Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(index.column()));
+         Brewtarget::logW(tr("Bad column: %1").arg(index.column()));
          return false;
    }
+   return retVal;
 }
 
 Fermentable* FermentableTableModel::getFermentable(unsigned int i)
@@ -649,15 +668,54 @@ QWidget* FermentableItemDelegate::createEditor(QWidget *parent, const QStyleOpti
       box->addItem(tr("Extract"));
       box->addItem(tr("Dry Extract"));
       box->addItem(tr("Adjunct"));
+
+      box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
       box->setFocusPolicy(Qt::StrongFocus);
+
       return box;
    }
    else if( index.column() == FERMISMASHEDCOL )
    {
-      QCheckBox* box = new QCheckBox(parent);
+      QComboBox* box = new QComboBox(parent);
+      QListWidget* list = new QListWidget(parent);
+      list->setResizeMode(QListWidget::Adjust);
+
+      list->addItem(tr("Mashed"));
+      list->addItem(tr("Steeped"));
+      list->addItem(tr("Not mashed"));
+      box->setModel(list->model());
+      box->setView(list);
+
+      box->setMinimumWidth(box->minimumSizeHint().width());
+      box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
+      box->setFocusPolicy(Qt::StrongFocus);
+
+      // Can we access to the data model into FermentableItemDelegate ? Yes we can !
+      int type = index.model()->index(index.row(), FERMTYPECOL).data(Qt::UserRole).toInt();
+
+      // Hide the unsuitable item keeping the same enumeration
+      if(type == Fermentable::Grain)
+      {
+         list->item(Fermentable::Not_Mashed)->setHidden(true);
+      }
+      else
+      {
+         list->item(Fermentable::Steeped)->setHidden(true);
+      }
+
+      return box;
+   }
+   else if( index.column() == FERMAFTERBOIL )
+   {
+      QComboBox* box = new QComboBox(parent);
+
+      box->addItem(tr("Normal"));
+      box->addItem(tr("Late"));
+
+      box->setMinimumWidth(box->minimumSizeHint().width());
+      box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
       box->setFocusPolicy(Qt::StrongFocus);
-      box->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
       return box;
    }
@@ -668,25 +726,18 @@ QWidget* FermentableItemDelegate::createEditor(QWidget *parent, const QStyleOpti
 void FermentableItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
    int col = index.column();
-   
-   if( col == FERMTYPECOL )
+
+   if( col == FERMTYPECOL || col == FERMISMASHEDCOL || col == FERMAFTERBOIL)
    {
       QComboBox* box = (QComboBox*)editor;
       int ndx = index.model()->data(index, Qt::UserRole).toInt();
 
       box->setCurrentIndex(ndx);
    }
-   else if( col == FERMISMASHEDCOL || col == FERMAFTERBOIL )
-   {
-      QCheckBox* checkBox = (QCheckBox*)editor;
-      Qt::CheckState checkState = (Qt::CheckState)index.model()->data(index, Qt::CheckStateRole).toInt();
-      
-      checkBox->setCheckState( checkState );
-   }
    else
    {
       QLineEdit* line = (QLineEdit*)editor;
-      
+
       line->setText(index.model()->data(index, Qt::DisplayRole).toString());
    }
 }
@@ -694,23 +745,26 @@ void FermentableItemDelegate::setEditorData(QWidget *editor, const QModelIndex &
 void FermentableItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
    int col = index.column();
-   
-   if( col == FERMTYPECOL )
+
+   if( col == FERMTYPECOL || col == FERMISMASHEDCOL || col == FERMAFTERBOIL )
    {
       QComboBox* box = qobject_cast<QComboBox*>(editor);
       int value = box->currentIndex();
       int ndx = model->data(index, Qt::UserRole).toInt();
-    
-     // Only do something when something needs to be done 
+
+     // Only do something when something needs to be done
       if ( value != ndx )
          model->setData(index, value, Qt::EditRole);
    }
    else if( col == FERMISMASHEDCOL || col == FERMAFTERBOIL )
    {
-      QCheckBox* checkBox = qobject_cast<QCheckBox*>(editor);
-      bool checked = (checkBox->checkState() == Qt::Checked);
-    
-      model->setData(index, checked, Qt::EditRole);
+      QComboBox* box = qobject_cast<QComboBox*>(editor);
+      int value = box->currentIndex();
+      int ndx = model->data(index, Qt::UserRole).toInt();
+
+     // Only do something when something needs to be done
+      if ( value != ndx )
+         model->setData(index, value, Qt::EditRole);
    }
    else
    {
