@@ -1,17 +1,22 @@
 /*
- * HopTableModel.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * HopTableModel.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Luke Vincent <luke.r.vincent@gmail.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
+ * - swstim <swstim@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -25,6 +30,7 @@
 #include <QStyleOptionViewItem>
 #include <QComboBox>
 #include <QLineEdit>
+#include <QHeaderView>
 
 #include "database.h"
 #include "hop.h"
@@ -36,20 +42,35 @@
 #include "brewtarget.h"
 
 HopTableModel::HopTableModel(QTableView* parent, bool editable)
-   : QAbstractTableModel(parent), colFlags(HOPNUMCOLS), recObs(0), parentTableWidget(parent), showIBUs(false)
+   : QAbstractTableModel(parent),
+     colFlags(HOPNUMCOLS),
+     _inventoryEditable(false),
+     recObs(0),
+     parentTableWidget(parent),
+     showIBUs(false)
 {
    hopObs.clear();
    setObjectName("hopTable");
-   
+
    int i;
    for( i = 0; i < HOPNUMCOLS; ++i )
    {
       if( i == HOPNAMECOL )
          colFlags[i] = Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled;
+      else if( i == HOPINVENTORYCOL )
+         colFlags[i] = Qt::ItemIsEnabled;
       else
          colFlags[i] = Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled |
             Qt::ItemIsEnabled;
    }
+
+   QHeaderView* headerView = parentTableWidget->horizontalHeader();
+   headerView->setContextMenuPolicy(Qt::CustomContextMenu);
+   parentTableWidget->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->setWordWrap(false);
+
+   connect(headerView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(contextMenu(const QPoint&)));
 }
 
 HopTableModel::~HopTableModel()
@@ -64,7 +85,7 @@ void HopTableModel::observeRecipe(Recipe* rec)
       disconnect( recObs, 0, this, 0 );
       removeAll();
    }
-   
+
    recObs = rec;
    if( recObs )
    {
@@ -105,50 +126,37 @@ void HopTableModel::addHop(Hop* hop)
       )
    )
       return;
-   
+
    int size = hopObs.size();
    beginInsertRows( QModelIndex(), size, size );
    hopObs.append(hop);
    connect( hop, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
    //reset(); // Tell everybody that the table has changed.
    endInsertRows();
-   
-   if( parentTableWidget )
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
 }
 
 void HopTableModel::addHops(QList<Hop*> hops)
 {
    QList<Hop*>::iterator i;
    QList<Hop*> tmp;
-   
+
    for( i = hops.begin(); i != hops.end(); i++ )
    {
       if( !hopObs.contains(*i) )
          tmp.append(*i);
    }
-   
+
    int size = hopObs.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       hopObs.append(tmp);
-      
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
          connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
 
       endInsertRows();
    }
-
-   if( parentTableWidget )
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
-   
 }
 
 bool HopTableModel::removeHop(Hop* hop)
@@ -163,15 +171,9 @@ bool HopTableModel::removeHop(Hop* hop)
       //reset(); // Tell everybody the table has changed.
       endRemoveRows();
 
-      if(parentTableWidget)
-      {
-         parentTableWidget->resizeColumnsToContents();
-         parentTableWidget->resizeRowsToContents();
-      }
-
       return true;
    }
-      
+
    return false;
 }
 
@@ -196,7 +198,7 @@ void HopTableModel::removeAll()
 void HopTableModel::changed(QMetaProperty prop, QVariant /*val*/)
 {
    int i;
-   
+
    // Find the notifier in the list
    Hop* hopSender = qobject_cast<Hop*>(sender());
    if( hopSender )
@@ -204,13 +206,13 @@ void HopTableModel::changed(QMetaProperty prop, QVariant /*val*/)
       i = hopObs.indexOf(hopSender);
       if( i < 0 )
          return;
-      
+
       emit dataChanged( QAbstractItemModel::createIndex(i, 0),
                         QAbstractItemModel::createIndex(i, HOPNUMCOLS-1));
       emit headerDataChanged( Qt::Vertical, i, i );
       return;
    }
-   
+
    // See if sender is our recipe.
    Recipe* recSender = qobject_cast<Recipe*>(sender());
    if( recSender && recSender == recObs )
@@ -240,13 +242,13 @@ QVariant HopTableModel::data( const QModelIndex& index, int role ) const
 {
    Hop* row;
    int col = index.column();
-   unitScale scale;
-   unitDisplay unit;
-   
+   Unit::unitScale scale;
+   Unit::unitDisplay unit;
+
    // Ensure the row is ok.
    if( index.row() >= (int)hopObs.size() )
    {
-      Brewtarget::log(Brewtarget::WARNING, QString("Bad model index. row = %1").arg(index.row()));
+      Brewtarget::logW(QString("Bad model index. row = %1").arg(index.row()));
       return QVariant();
    }
    else
@@ -264,6 +266,14 @@ QVariant HopTableModel::data( const QModelIndex& index, int role ) const
             return QVariant( Brewtarget::displayAmount(row->alpha_pct(), 0) );
          else
             return QVariant();
+      case HOPINVENTORYCOL:
+         if( role != Qt::DisplayRole )
+            return QVariant();
+         unit = displayUnit(col);
+         scale = displayScale(col);
+
+         return QVariant(Brewtarget::displayAmount(row->inventory(), Units::kilograms, 3, unit, scale));
+
       case HOPAMOUNTCOL:
          if( role != Qt::DisplayRole )
             return QVariant();
@@ -280,10 +290,12 @@ QVariant HopTableModel::data( const QModelIndex& index, int role ) const
          else
             return QVariant();
       case HOPTIMECOL:
-         if( role == Qt::DisplayRole )
-            return QVariant( Brewtarget::displayAmount(row->time_min(), Units::minutes) );
-         else
+         if( role != Qt::DisplayRole )
             return QVariant();
+
+         scale = displayScale(col);
+
+         return QVariant( Brewtarget::displayAmount(row->time_min(), Units::minutes, 0, Unit::noUnit, scale) );
       case HOPFORMCOL:
         if ( role == Qt::DisplayRole )
           return QVariant( row->formStringTr() );
@@ -292,7 +304,7 @@ QVariant HopTableModel::data( const QModelIndex& index, int role ) const
         else
            return QVariant();
       default :
-         Brewtarget::log(Brewtarget::WARNING, QString("HopTableModel::data Bad column: %1").arg(index.column()));
+         Brewtarget::logW(QString("HopTableModel::data Bad column: %1").arg(index.column()));
          return QVariant();
    }
 }
@@ -307,6 +319,8 @@ QVariant HopTableModel::headerData( int section, Qt::Orientation orientation, in
             return QVariant(tr("Name"));
          case HOPALPHACOL:
             return QVariant(tr("Alpha %"));
+         case HOPINVENTORYCOL:
+            return QVariant(tr("Inventory"));
          case HOPAMOUNTCOL:
             return QVariant(tr("Amount"));
          case HOPUSECOL:
@@ -316,7 +330,7 @@ QVariant HopTableModel::headerData( int section, Qt::Orientation orientation, in
          case HOPFORMCOL:
             return QVariant(tr("Form"));
          default:
-            Brewtarget::log(Brewtarget::WARNING, QString("HopTableModel::headerdata Bad column: %1").arg(section));
+            Brewtarget::logW(QString("HopTableModel::headerdata Bad column: %1").arg(section));
             return QVariant();
       }
    }
@@ -333,109 +347,99 @@ QVariant HopTableModel::headerData( int section, Qt::Orientation orientation, in
 Qt::ItemFlags HopTableModel::flags(const QModelIndex& index ) const
 {
    int col = index.column();
-   
+
    return colFlags[col];
 }
 
 bool HopTableModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
    Hop *row;
-   QString val;
-   
+   bool retVal = false;
+   double amt;
+
    if( index.row() >= (int)hopObs.size() || role != Qt::EditRole )
       return false;
-   else
-      row = hopObs[index.row()];
-   
+
+   row = hopObs[index.row()];
+
    switch( index.column() )
    {
       case HOPNAMECOL:
-         if( value.canConvert(QVariant::String))
-         {
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
             row->setName(value.toString());
-            return true;
-         }
-         else
-            return false;
+         break;
       case HOPALPHACOL:
-         if( value.canConvert(QVariant::Double) )
+         retVal = value.canConvert(QVariant::Double);
+         if( retVal )
          {
-            row->setAlpha_pct( value.toDouble() );
-            headerDataChanged( Qt::Vertical, index.row(), index.row() ); // Need to re-show header (IBUs).
-            return true;
+            amt = Brewtarget::toDouble( value.toString(), &retVal );
+            if ( ! retVal )
+               Brewtarget::logW( QString("HopTableModel::setData() could not convert %1 to double").arg(value.toString()));
+            row->setAlpha_pct( amt );
          }
-         else
-            return false;
-      case HOPAMOUNTCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            val = value.toString();
-            if (!Brewtarget::hasUnits(val))
-               val = QString("%1%2").arg(val).arg( Brewtarget::getWeightUnitSystem() == SI ? "g" : "oz");
+         break;
 
-            row->setAmount_kg( Brewtarget::weightQStringToSI(val));
-            headerDataChanged( Qt::Vertical, index.row(), index.row() ); // Need to re-show header (IBUs).
-            return true;
-         }
-         else
-            return false;
+      case HOPINVENTORYCOL:
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
+            row->setInventoryAmount( Brewtarget::qStringToSI(value.toString(),Units::kilograms, displayUnit(HOPINVENTORYCOL)));
+         break;
+      case HOPAMOUNTCOL:
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
+            row->setAmount_kg( Brewtarget::qStringToSI(value.toString(), Units::kilograms, displayUnit(HOPAMOUNTCOL)));
+         break;
       case HOPUSECOL:
-         if( value.canConvert(QVariant::Int) )
-         {
+         retVal = value.canConvert(QVariant::Int);
+         if( retVal )
             row->setUse(static_cast<Hop::Use>(value.toInt()));
-            headerDataChanged( Qt::Vertical, index.row(), index.row() ); // Need to re-show header (IBUs).
-            return true;
-         }
-         else
-            return false;
+         break;
       case HOPFORMCOL:
-         if( value.canConvert(QVariant::Int))
-         {
+         retVal = value.canConvert(QVariant::Int);
+         if( retVal )
             row->setForm(static_cast<Hop::Form>(value.toInt()));
-            headerDataChanged( Qt::Vertical, index.row(), index.row() );
-            return true;
-         }
+         break;
       case HOPTIMECOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            double min = Brewtarget::timeQStringToSI(value.toString());
-            row->setTime_min( min );
-            headerDataChanged( Qt::Vertical, index.row(), index.row() ); // Need to re-show header (IBUs).
-            return true;
-         }
-         else
-            return false;
+         retVal = value.canConvert(QVariant::String);
+         if( retVal )
+            row->setTime_min( Brewtarget::qStringToSI(value.toString(),Units::minutes));
+         break;
       default:
-         Brewtarget::log(Brewtarget::WARNING, QString("HopTableModel::setdata Bad column: %1").arg(index.column()));
+         Brewtarget::logW(QString("HopTableModel::setdata Bad column: %1").arg(index.column()));
          return false;
    }
+   if ( retVal )
+      headerDataChanged( Qt::Vertical, index.row(), index.row() ); // Need to re-show header (IBUs).
+
+   return retVal;
 }
 
-unitDisplay HopTableModel::displayUnit(int column) const
-{ 
+Unit::unitDisplay HopTableModel::displayUnit(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noUnit;
+      return Unit::noUnit;
 
-   return (unitDisplay)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::UNIT).toInt();
+   return (Unit::unitDisplay)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::UNIT).toInt();
 }
 
-unitScale HopTableModel::displayScale(int column) const
-{ 
+Unit::unitScale HopTableModel::displayScale(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noScale;
+      return Unit::noScale;
 
-   return (unitScale)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::SCALE).toInt();
+   return (Unit::unitScale)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::SCALE).toInt();
 }
 
 // We need to:
 //   o clear the custom scale if set
 //   o clear any custom unit from the rows
 //      o which should have the side effect of clearing any scale
-void HopTableModel::setDisplayUnit(int column, unitDisplay displayUnit) 
+void HopTableModel::setDisplayUnit(int column, Unit::unitDisplay displayUnit)
 {
    // Hop* row; // disabled per-cell magic
    QString attribute = generateName(column);
@@ -443,21 +447,21 @@ void HopTableModel::setDisplayUnit(int column, unitDisplay displayUnit)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayUnit,this,Brewtarget::UNIT); 
-   Brewtarget::setOption(attribute,noScale,this,Brewtarget::SCALE);
+   Brewtarget::setOption(attribute,displayUnit,this->objectName(),Brewtarget::UNIT);
+   Brewtarget::setOption(attribute,Unit::noScale,this->objectName(),Brewtarget::SCALE);
 
    /* Disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getHop(i);
-      row->setDisplayUnit(noUnit);
+      row->setDisplayUnit(Unit::noUnit);
    }
    */
 }
 
 // Setting the scale should clear any cell-level scaling options
-void HopTableModel::setDisplayScale(int column, unitScale displayScale) 
-{ 
+void HopTableModel::setDisplayScale(int column, Unit::unitScale displayScale)
+{
    // Fermentable* row; //disabled per-cell magic
 
    QString attribute = generateName(column);
@@ -465,13 +469,13 @@ void HopTableModel::setDisplayScale(int column, unitScale displayScale)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayScale,this,Brewtarget::SCALE); 
+   Brewtarget::setOption(attribute,displayScale,this->objectName(),Brewtarget::SCALE);
 
    /* disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getHop(i);
-      row->setDisplayScale(noScale);
+      row->setDisplayScale(Unit::noScale);
    }
    */
 }
@@ -482,20 +486,67 @@ QString HopTableModel::generateName(int column) const
 
    switch(column)
    {
+      case HOPINVENTORYCOL:
+         attribute = "inventory_kg";
+         break;
       case HOPAMOUNTCOL:
          attribute = "amount_kg";
          break;
+      case HOPTIMECOL:
+         attribute = "time_min";
+         break;
       default:
          attribute = "";
    }
    return attribute;
 }
 
+void HopTableModel::contextMenu(const QPoint &point)
+{
+   QObject* calledBy = sender();
+   QHeaderView* hView = qobject_cast<QHeaderView*>(calledBy);
+
+   int selected = hView->logicalIndexAt(point);
+   Unit::unitDisplay currentUnit;
+   Unit::unitScale  currentScale;
+
+   // Since we need to call generateVolumeMenu() two different ways, we need
+   // to figure out the currentUnit and Scale here
+   currentUnit  = displayUnit(selected);
+   currentScale = displayScale(selected);
+
+   QMenu* menu;
+   QAction* invoked;
+
+   switch(selected)
+   {
+      case HOPINVENTORYCOL:
+      case HOPAMOUNTCOL:
+         menu = Brewtarget::setupMassMenu(parentTableWidget,currentUnit, currentScale);
+         break;
+      case HOPTIMECOL:
+         menu = Brewtarget::setupTimeMenu(parentTableWidget,currentScale);
+         break;
+      default:
+         return;
+   }
+
+   invoked = menu->exec(hView->mapToGlobal(point));
+   if ( invoked == 0 )
+      return;
+
+   QWidget* pMenu = invoked->parentWidget();
+   if ( selected != HOPTIMECOL && pMenu == menu )
+      setDisplayUnit(selected,(Unit::unitDisplay)invoked->data().toInt());
+   else
+      setDisplayScale(selected,(Unit::unitScale)invoked->data().toInt());
+
+}
+
 // Returns null on failure.
-Hop* HopTableModel::getHop(unsigned int i){
-    //std::cerr << "HopTableModel::getHop( " << i << "/" << hopObs.size()  << " )" << std::endl;
-    if(!(hopObs.isEmpty())){
-        if(static_cast<int>(i) < hopObs.size())
+Hop* HopTableModel::getHop(int i) {
+    if(!(hopObs.isEmpty())) {
+        if(i >= 0 && i < hopObs.size())
             return hopObs[i];
     }
     else
@@ -509,7 +560,7 @@ HopItemDelegate::HopItemDelegate(QObject* parent)
         : QItemDelegate(parent)
 {
 }
-        
+
 QWidget* HopItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem& /*option*/, const QModelIndex &index) const
 {
    if ( index.column() == HOPUSECOL )
@@ -522,6 +573,7 @@ QWidget* HopItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewIt
       box->addItem(tr("Boil"));
       box->addItem(tr("Aroma"));
       box->addItem(tr("Dry Hop"));
+      box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
       return box;
@@ -533,7 +585,7 @@ QWidget* HopItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewIt
       box->addItem(tr("Leaf"));
       box->addItem(tr("Pellet"));
       box->addItem(tr("Plug"));
-
+      box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
       return box;
