@@ -1,17 +1,20 @@
 /*
- * MashDesigner.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2010-2013.
+ * MashDesigner.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Dan Cavanagh <dan@dancavanagh.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -53,7 +56,7 @@ MashDesigner::MashDesigner(QWidget* parent) : QDialog(parent)
    connect( horizontalSlider_amount, SIGNAL(valueChanged(int)), this, SLOT(updateAmt()) );
    connect( horizontalSlider_temp, SIGNAL(valueChanged(int)), this, SLOT(updateTemp()) );
    // Save the target temp whenever it's changed.
-   connect( lineEdit_temp, SIGNAL(editingFinished()), this, SLOT(saveTargetTemp()) );
+   connect( lineEdit_temp, SIGNAL(textModified()), this, SLOT(saveTargetTemp()) );
    // Move to next step.
    connect( pushButton_next, SIGNAL(clicked()), this, SLOT(proceed()) );
    // Do correct calcs when the mash step type is selected.
@@ -61,6 +64,7 @@ MashDesigner::MashDesigner(QWidget* parent) : QDialog(parent)
 
    connect( checkBox_batchSparge, SIGNAL(clicked()), this, SLOT(updateMaxAmt()) );
    connect( pushButton_finish, SIGNAL(clicked()), this, SLOT(saveAndClose()) );
+
 }
 
 void MashDesigner::proceed()
@@ -144,8 +148,8 @@ void MashDesigner::saveStep()
    //mashStep->disableNotification();
    mashStep->setName( lineEdit_name->text() );
    mashStep->setType( type );
-   mashStep->setStepTemp_c( Brewtarget::tempQStringToSI(lineEdit_temp->text()) );
-   mashStep->setStepTime_min( Brewtarget::timeQStringToSI(lineEdit_time->text()) );
+   mashStep->setStepTemp_c(   Brewtarget::qStringToSI(lineEdit_temp->text(), Units::celsius) );
+   mashStep->setStepTime_min( Brewtarget::qStringToSI(lineEdit_time->text(), Units::minutes) );
 
    if( type == MashStep::Infusion)
    {
@@ -295,7 +299,7 @@ bool MashDesigner::initializeMash()
       return false;
    
    //otherwise continue - get the text and keep going
-   mash->setTunTemp_c( Brewtarget::tempQStringToSI( dialogText ) );
+   mash->setTunTemp_c( Brewtarget::qStringToSI( dialogText, Units::celsius ) );
 
    mash->removeAllMashSteps();
    curStep = 0;
@@ -485,8 +489,10 @@ void MashDesigner::updateTemp()
 
 void MashDesigner::saveTargetTemp()
 {
-   double temp = Brewtarget::tempQStringToSI(lineEdit_temp->text());
+   double temp = lineEdit_temp->toSI();
 
+   // be nice and reset the field so it displays in proper units
+   lineEdit_temp->setText(temp);
    if( mashStep != 0 )
       mashStep->setStepTemp_c(temp);
 
@@ -519,7 +525,7 @@ double MashDesigner::getDecoctionAmount_l()
    if( prevStep == 0 )
    {
       QMessageBox::critical(this, tr("Decoction error"), tr("The first mash step cannot be a decoction."));
-      Brewtarget::log(Brewtarget::ERROR, QString("MashDesigner: First step not a decoction."));
+      Brewtarget::logE(QString("MashDesigner: First step not a decoction."));
       return 0;
    }
    t1 = prevStep->stepTemp_c();
@@ -578,3 +584,4 @@ void MashDesigner::typeChanged(int t)
       horizontalSlider_temp->setEnabled(false);
    }
 }
+
