@@ -1,17 +1,20 @@
 /*
- * MashEditor.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * MashEditor.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,6 +35,7 @@ MashEditor::MashEditor(QWidget* parent) : QDialog(parent), mashObs(0)
    connect(pushButton_fromEquipment, SIGNAL(clicked()), this, SLOT(fromEquipment()) );
    connect(this, SIGNAL(accepted()), this, SLOT(saveAndClose()) );
    connect(this, SIGNAL(rejected()), this, SLOT(closeEditor()) );
+
 }
 
 void MashEditor::showEditor()
@@ -50,21 +54,18 @@ void MashEditor::saveAndClose()
    if( mashObs == 0 )
       return;
    
-   //mash->disableNotification(); // If we don't do this, the notification will propagate to a showChanges() and we'll lose any info we want saved.
    mashObs->setEquipAdjust( true ); // BeerXML won't like me, but it's just stupid not to adjust for the equipment when you're able.
 
    mashObs->setName( lineEdit_name->text() );
-   mashObs->setGrainTemp_c(Brewtarget::tempQStringToSI(lineEdit_grainTemp->text()));
-   mashObs->setSpargeTemp_c(Brewtarget::tempQStringToSI(lineEdit_spargeTemp->text()));
-   mashObs->setPh(lineEdit_spargePh->text().toDouble());
-   mashObs->setTunTemp_c(Brewtarget::tempQStringToSI(lineEdit_tunTemp->text()));
-   mashObs->setTunWeight_kg(Brewtarget::weightQStringToSI(lineEdit_tunMass->text()));
-   mashObs->setTunSpecificHeat_calGC(lineEdit_tunSpHeat->text().toDouble() );
+   mashObs->setGrainTemp_c(lineEdit_grainTemp->toSI());
+   mashObs->setSpargeTemp_c(lineEdit_spargeTemp->toSI());
+   mashObs->setPh(lineEdit_spargePh->toSI());
+   mashObs->setTunTemp_c(lineEdit_tunTemp->toSI());
+   mashObs->setTunWeight_kg(lineEdit_tunMass->toSI());
+   mashObs->setTunSpecificHeat_calGC(lineEdit_tunSpHeat->toSI());
 
    mashObs->setNotes( textEdit_notes->toPlainText() );
    
-   //mash->reenableNotification();
-   //mash->forceNotify();
 }
 
 void MashEditor::fromEquipment()
@@ -75,8 +76,8 @@ void MashEditor::fromEquipment()
    if ( equip == 0 )
       return;
 
-   lineEdit_tunMass->setText(Brewtarget::displayAmount(equip->tunWeight_kg(), Units::kilograms));
-   lineEdit_tunSpHeat->setText(Brewtarget::displayAmount(equip->tunSpecificHeat_calGC()));
+   lineEdit_tunMass->setText(equip);
+   lineEdit_tunSpHeat->setText(equip);
 }
 
 void MashEditor::setMash(Mash* mash)
@@ -137,32 +138,32 @@ void MashEditor::showChanges(QMetaProperty* prop)
          return;
    }
    if( propName == "grainTemp_c" || updateAll ) {
-      lineEdit_grainTemp->setText(Brewtarget::displayAmount(mashObs->grainTemp_c(), Units::celsius));
+      lineEdit_grainTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
    if( propName == "spargeTemp_c" || updateAll ) {
-      lineEdit_spargeTemp->setText(Brewtarget::displayAmount(mashObs->spargeTemp_c(), Units::celsius));
+      lineEdit_spargeTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
    if( propName == "ph" || updateAll ) {
-      lineEdit_spargePh->setText(Brewtarget::displayAmount(mashObs->ph()));
+      lineEdit_spargePh->setText(mashObs);
       if( ! updateAll )
          return;
    }
    if( propName == "tunTemp_c" || updateAll ) {
-      lineEdit_tunTemp->setText(Brewtarget::displayAmount(mashObs->tunTemp_c(), Units::celsius));
+      lineEdit_tunTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
    if( propName == "tunMass_kg" || updateAll ) {
-      lineEdit_tunMass->setText(Brewtarget::displayAmount(mashObs->tunWeight_kg(), Units::kilograms));
+      lineEdit_tunMass->setText(mashObs);
       if( ! updateAll )
          return;
    }
    if( propName == "tunSpecificHeat_calGC" || updateAll ) {
-      lineEdit_tunSpHeat->setText(Brewtarget::displayAmount(mashObs->tunSpecificHeat_calGC()));
+      lineEdit_tunSpHeat->setText(mashObs);
       if( ! updateAll )
          return;
    }
@@ -175,13 +176,13 @@ void MashEditor::showChanges(QMetaProperty* prop)
 
 void MashEditor::clear()
 {
-   lineEdit_name->setText("");
-   lineEdit_grainTemp->setText("");
-   lineEdit_spargeTemp->setText("");
-   lineEdit_spargePh->setText("");
-   lineEdit_tunTemp->setText("");
-   lineEdit_tunMass->setText("");
-   lineEdit_tunSpHeat->setText("");
+   lineEdit_name->setText(QString(""));
+   lineEdit_grainTemp->setText(QString(""));
+   lineEdit_spargeTemp->setText(QString(""));
+   lineEdit_spargePh->setText(QString(""));
+   lineEdit_tunTemp->setText(QString(""));
+   lineEdit_tunMass->setText(QString(""));
+   lineEdit_tunSpHeat->setText(QString(""));
 
-   textEdit_notes->setPlainText("");
+   textEdit_notes->setPlainText(QString(""));
 }
