@@ -1,17 +1,22 @@
 /*
- * MashWizard.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * MashWizard.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - David Grundberg <individ@acc.umu.se>
+ * - Jeff Bailey <skydvr38@verizon.net>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Rob Taylor <robtaylor@floopily.org>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -55,33 +60,8 @@ void MashWizard::show()
       return;
    }
 
-   switch (Brewtarget::getWeightUnitSystem())
-   {
-      case USCustomary:
-      case Imperial:
-         weightUnit = Units::pounds;
-         break;
-      case SI:
-      default:
-         weightUnit = Units::kilograms;
-         break;
-   }
-   switch (Brewtarget::getVolumeUnitSystem())
-   {
-      case USCustomary:
-         volumeUnit = Units::us_quarts;
-         break;
-      case Imperial:
-         volumeUnit = Units::imperial_quarts;   
-         break;
-      case SI:
-      default:
-         volumeUnit = Units::liters;
-         break;
-   }
-
-
-   label->setText(tr("Mash thickness (%1/%2)").arg(volumeUnit->getUnitName(),weightUnit->getUnitName()));
+   Brewtarget::getThicknessUnits(&volumeUnit,&weightUnit);
+   label_mashThickness->setText(tr("Mash thickness (%1/%2)").arg(volumeUnit->getUnitName(),weightUnit->getUnitName()));
    
    setVisible(true);
 }
@@ -103,6 +83,8 @@ void MashWizard::wizardry()
    double absorption_LKg;
    double boilingPoint_c; 
 
+   bool ok = false;
+
    // If we have an equipment, utilize the custom absorption and boiling temp.
    if( recObs->equipment() != 0 )
    {
@@ -115,7 +97,10 @@ void MashWizard::wizardry()
       boilingPoint_c = 100.0;
    }
 
-   thickNum = lineEdit_mashThickness->text().toDouble();
+   thickNum = Brewtarget::toDouble(lineEdit_mashThickness->text(), &ok);
+   if ( ! ok ) 
+      Brewtarget::logW( QString("MashWizard::wizardry() could not convert %1 to double").arg(lineEdit_mashThickness->text()));
+
    thickness_LKg = thickNum * volumeUnit->toSI(1) / weightUnit->toSI(1);
 
    if( thickness_LKg <= 0.0 )
@@ -211,7 +196,7 @@ void MashWizard::wizardry()
          if( r < 0 || r > 1 )
          {
             QMessageBox::critical(this, tr("Decoction error"), tr("Something went wrong in decoction calculation.") );
-            Brewtarget::log(Brewtarget::ERROR, QString("Decoction: r=%1").arg(r));
+            Brewtarget::logE(QString("Decoction: r=%1").arg(r));
             return;
          }
 
@@ -231,15 +216,31 @@ void MashWizard::wizardry()
       }
    }
    
-   // Now, do a sparge step to get the total volume of the mash up to the boil size.
-   double wortInBoil_l = recObs->wortFromMash_l();
+   // Now, do a sparge step, using just enough water that the total
+   // volume sums up to the target pre-boil size.
+   double spargeWater_l = recObs->boilSize_l() - recObs->wortFromMash_l();
+
    if( recObs->equipment() != 0 )
    {
-      wortInBoil_l += recObs->equipment()->topUpKettle_l();
-      wortInBoil_l -= recObs->equipment()->lauterDeadspace_l();
+      // These variables are part of the boil size but not the wort
+      // size and the wizard should account for that.
+      spargeWater_l += recObs->equipment()->lauterDeadspace_l();
+      spargeWater_l -= recObs->equipment()->topUpKettle_l();
+   }
+
+   // Need to account for extract/sugar volume also.
+   QList<Fermentable*> ferms = recObs->fermentables();
+   foreach( Fermentable* f, ferms )
+   {
+      Fermentable::Type type = f->type();
+      if( type == Fermentable::Extract )
+         spargeWater_l -= f->amount_kg() / PhysicalConstants::liquidExtractDensity_kgL;
+      else if( type == Fermentable::Sugar )
+         spargeWater_l -= f->amount_kg() / PhysicalConstants::sucroseDensity_kgL;
+      else if( type == Fermentable::Dry_Extract )
+         spargeWater_l -= f->amount_kg() / PhysicalConstants::dryExtractDensity_kgL;
    }
 
-   double spargeWater_l = recObs->boilSize_l() - wortInBoil_l;
    if( spargeWater_l >= 0.0 )
    {
       // If the recipe already has a mash step named "Final Batch Sparge",
