@@ -1,17 +1,20 @@
 /*
- * MiscEditor.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * MiscEditor.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -32,6 +35,7 @@ MiscEditor::MiscEditor( QWidget* parent )
    
    connect( buttonBox, SIGNAL( accepted() ), this, SLOT( save() ));
    connect( buttonBox, SIGNAL( rejected() ), this, SLOT( clearAndClose() ));
+
 }
 
 void MiscEditor::setMisc( Misc* m )
@@ -57,24 +61,16 @@ void MiscEditor::save()
       return;
    }
    
-   // TODO: check this out with 1.2.5.
-   // Need to disable notification since every "set" method will cause a "showChanges" that
-   // will revert any changes made.
-   //m->disableNotification();
-
    m->setName(lineEdit_name->text());
    m->setType( static_cast<Misc::Type>(comboBox_type->currentIndex()) );
    m->setUse( static_cast<Misc::Use>(comboBox_use->currentIndex()) );
    // TODO: fill in the rest of the "set" methods.
-   m->setTime(Brewtarget::timeQStringToSI(lineEdit_time->text()));
+   m->setTime(lineEdit_time->toSI());
    m->setAmountIsWeight( (checkBox_isWeight->checkState() == Qt::Checked)? true : false );
-   m->setAmount( m->amountIsWeight() ? Brewtarget::weightQStringToSI(lineEdit_amount->text()) : Brewtarget::volQStringToSI(lineEdit_amount->text()));
+   m->setAmount( lineEdit_amount->toSI());
    m->setUseFor(textEdit_useFor->toPlainText());
    m->setNotes( textEdit_notes->toPlainText() );
 
-   //m->reenableNotification();
-   //m->forceNotify();
-
    setVisible(false);
 }
 
@@ -127,13 +123,13 @@ void MiscEditor::showChanges(QMetaProperty* metaProp)
    }
    if( propName == "time" || updateAll )
    {
-      lineEdit_time->setText(Brewtarget::displayAmount(obsMisc->time(), Units::minutes));
+      lineEdit_time->setText(obsMisc);
       if( ! updateAll )
          return;
    }
    if( propName == "amount" || updateAll )
    {
-      lineEdit_amount->setText(Brewtarget::displayAmount(obsMisc->amount(), (obsMisc->amountIsWeight()) ? (Unit*)Units::kilograms : (Unit*)Units::liters  ));
+      lineEdit_amount->setText(obsMisc);
       if( ! updateAll )
          return;
    }
@@ -143,6 +139,12 @@ void MiscEditor::showChanges(QMetaProperty* metaProp)
       if( ! updateAll )
          return;
    }
+   if( propName == "inventory" || updateAll )
+   {
+      lineEdit_inventory->setText(obsMisc);
+      if( ! updateAll )
+         return;
+   }
    if( propName == "useFor" || updateAll )
    {
       textEdit_useFor->setPlainText( obsMisc->useFor() );
