@@ -1,22 +1,22 @@
 /*
- * UnitSystems.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * UnitSystems.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "UnitSystems.h"
 #include "USWeightUnitSystem.h"
 #include "SIWeightUnitSystem.h"
@@ -26,6 +26,12 @@
 #include "CelsiusTempUnitSystem.h"
 #include "FahrenheitTempUnitSystem.h"
 #include "TimeUnitSystem.h"
+#include "EbcColorUnitSystem.h"
+#include "SrmColorUnitSystem.h"
+#include "SgDensityUnitSystem.h"
+#include "PlatoDensityUnitSystem.h"
+#include "unit.h"
+#include <QDebug>
 
 USWeightUnitSystem* UnitSystems::usWeightUnitSystem()
 {
@@ -75,3 +81,27 @@ TimeUnitSystem* UnitSystems::timeUnitSystem()
    return t;
 }
 
+EbcColorUnitSystem* UnitSystems::ebcColorUnitSystem()
+{
+   static EbcColorUnitSystem* e = new EbcColorUnitSystem();
+   return e;
+}
+
+SrmColorUnitSystem* UnitSystems::srmColorUnitSystem()
+{
+   static SrmColorUnitSystem* s = new SrmColorUnitSystem();
+   return s;
+}
+
+SgDensityUnitSystem* UnitSystems::sgDensityUnitSystem()
+{
+   static SgDensityUnitSystem* sg = new SgDensityUnitSystem();
+   return sg;
+}
+
+PlatoDensityUnitSystem* UnitSystems::platoDensityUnitSystem()
+{
+   static PlatoDensityUnitSystem* p = new PlatoDensityUnitSystem();
+   return p;
+}
+
