@@ -1,17 +1,20 @@
 /*
- * WaterTableModel.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * WaterTableModel.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - swstim <swstim@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -88,9 +91,10 @@ void WaterTableModel::addWater(Water* water)
    )
       return;
    
+   beginInsertRows( QModelIndex(), waterObs.size(), waterObs.size() );
    waterObs.append(water);
    connect( water, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
-   reset(); // Tell everybody that the table has changed.
+   endInsertRows();
    
    if(parentTableWidget)
    {
@@ -137,9 +141,10 @@ void WaterTableModel::removeWater(Water* water)
    i = waterObs.indexOf(water);
    if( i >= 0 )
    {
+      beginRemoveRows( QModelIndex(), i, i );
       disconnect( water, 0, this, 0 );
       waterObs.removeAt(i);
-      reset(); // Tell everybody the table has changed.
+      endRemoveRows();
          
       if(parentTableWidget)
       {
@@ -192,7 +197,7 @@ QVariant WaterTableModel::data( const QModelIndex& index, int role ) const
    // Ensure the row is ok.
    if( index.row() >= (int)waterObs.size() )
    {
-      Brewtarget::log(Brewtarget::WARNING, tr("Bad model index. row = %1").arg(index.row()));
+      Brewtarget::logW(tr("Bad model index. row = %1").arg(index.row()));
       return QVariant();
    }
    else
@@ -221,7 +226,7 @@ QVariant WaterTableModel::data( const QModelIndex& index, int role ) const
       case WATERMAGNESIUMCOL:
          return QVariant( Brewtarget::displayAmount(row->magnesium_ppm(), 0) );
       default :
-         Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(index.column()));
+         Brewtarget::logW(tr("Bad column: %1").arg(index.column()));
          return QVariant();
    }
 }
@@ -249,7 +254,7 @@ QVariant WaterTableModel::headerData( int section, Qt::Orientation orientation,
          case WATERMAGNESIUMCOL:
             return QVariant(tr("Magnesium (ppm)"));
          default:
-            Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(section));
+            Brewtarget::logW(tr("Bad column: %1").arg(section));
             return QVariant();
       }
    }
@@ -273,82 +278,49 @@ Qt::ItemFlags WaterTableModel::flags(const QModelIndex& index ) const
 bool WaterTableModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
    Water *row;
+   bool retval = false;
 
    if( index.row() >= (int)waterObs.size() || role != Qt::EditRole )
       return false;
    else
       row = waterObs[index.row()];
 
+   retval = value.canConvert(QVariant::String);
+   if ( ! retval )
+      return retval;
+
    switch( index.column() )
    {
       case WATERNAMECOL:
-         if( value.canConvert(QVariant::String))
-         {
-            row->setName(value.toString());
-            return true;
-         }
-         else
-            return false;
+         row->setName(value.toString());
+         break;
       case WATERAMOUNTCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setAmount_l( Brewtarget::volQStringToSI(value.toString()) );
-            return true;
-         }
-         else
-            return false;
+         row->setAmount_l( Brewtarget::qStringToSI(value.toString(), Units::liters) );
+         break;
       case WATERCALCIUMCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setCalcium_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setCalcium_ppm( Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       case WATERBICARBONATECOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setBicarbonate_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setBicarbonate_ppm(Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       case WATERSULFATECOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setSulfate_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setSulfate_ppm( Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       case WATERCHLORIDECOL:
-         if( value.canConvert(QVariant::String))
-         {
-            row->setChloride_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setChloride_ppm( Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       case WATERSODIUMCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setSodium_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setSodium_ppm( Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       case WATERMAGNESIUMCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setMagnesium_ppm( value.toString().toDouble() );
-            return true;
-         }
-         else
-            return false;
+         row->setMagnesium_ppm( Brewtarget::toDouble(value.toString(), "WaterTableModel::setData()"));
+         break;
       default:
-         Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(index.column()));
-         return false;
+         retval = false;
+         Brewtarget::logW(tr("Bad column: %1").arg(index.column()));
    }
+
+   return retval;
 }
 
 //==========================CLASS HopItemDelegate===============================
