@@ -1,17 +1,19 @@
 /*
- * YeastDialog.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * YeastDialog.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2015
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -33,29 +35,89 @@
 YeastDialog::YeastDialog(MainWindow* parent)
         : QDialog(parent), mainWindow(parent), yeastEditor(new YeastEditor(this)), numYeasts(0)
 {
-   setupUi(this);
+   doLayout();
 
-   yeastTableModel = new YeastTableModel(yeastTableWidget, false);
-   yeastTableProxy = new YeastSortFilterProxyModel(yeastTableWidget);
+   yeastTableModel = new YeastTableModel(tableWidget, false);
+   yeastTableModel->setInventoryEditable(true);
+   yeastTableProxy = new YeastSortFilterProxyModel(tableWidget);
    yeastTableProxy->setSourceModel(yeastTableModel);
-   yeastTableWidget->setModel(yeastTableProxy);
-   yeastTableWidget->setSortingEnabled(true);
-   yeastTableWidget->sortByColumn( YEASTNAMECOL, Qt::AscendingOrder );
+   tableWidget->setModel(yeastTableProxy);
+   tableWidget->setSortingEnabled(true);
+   tableWidget->sortByColumn( YEASTNAMECOL, Qt::AscendingOrder );
    yeastTableProxy->setDynamicSortFilter(true);
-   
+   yeastTableProxy->setFilterKeyColumn(1);
+
    connect( pushButton_addToRecipe, SIGNAL( clicked() ), this, SLOT( addYeast() ) );
    connect( pushButton_edit, SIGNAL( clicked() ), this, SLOT( editSelected() ) );
    connect( pushButton_new, SIGNAL( clicked() ), this, SLOT( newYeast() ) );
    connect( pushButton_remove, SIGNAL(clicked()), this, SLOT( removeYeast() ) );
-   connect( yeastTableWidget, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT( addYeast(const QModelIndex&) ) );
+   connect( tableWidget, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT( addYeast(const QModelIndex&) ) );
+   connect( qLineEdit_searchBox, SIGNAL(textEdited(QString)), this, SLOT(filterYeasts(QString)));
 
    yeastTableModel->observeDatabase(true);
 
 }
 
+void YeastDialog::doLayout()
+{
+   resize(800, 300);
+   verticalLayout = new QVBoxLayout(this);
+      tableWidget = new QTableView(this);
+      horizontalLayout = new QHBoxLayout();
+         horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
+         qLineEdit_searchBox = new QLineEdit();
+         qLineEdit_searchBox->setMaxLength(30);
+         qLineEdit_searchBox->setPlaceholderText("Enter filter");
+         pushButton_addToRecipe = new QPushButton(this);
+            pushButton_addToRecipe->setObjectName(QStringLiteral("pushButton_addToRecipe"));
+            pushButton_addToRecipe->setAutoDefault(false);
+            pushButton_addToRecipe->setDefault(true);
+         pushButton_new = new QPushButton(this);
+            pushButton_new->setObjectName(QStringLiteral("pushButton_new"));
+            pushButton_new->setAutoDefault(false);
+         pushButton_edit = new QPushButton(this);
+            pushButton_edit->setObjectName(QStringLiteral("pushButton_edit"));
+            QIcon icon;
+            icon.addFile(QStringLiteral(":/images/edit.svg"), QSize(), QIcon::Normal, QIcon::Off);
+            pushButton_edit->setIcon(icon);
+            pushButton_edit->setAutoDefault(false);
+         pushButton_remove = new QPushButton(this);
+            pushButton_remove->setObjectName(QStringLiteral("pushButton_remove"));
+            QIcon icon1;
+            icon1.addFile(QStringLiteral(":/images/smallMinus.svg"), QSize(), QIcon::Normal, QIcon::Off);
+            pushButton_remove->setIcon(icon1);
+            pushButton_remove->setAutoDefault(false);
+         horizontalLayout->addWidget(qLineEdit_searchBox);
+         horizontalLayout->addItem(horizontalSpacer);
+         horizontalLayout->addWidget(pushButton_addToRecipe);
+         horizontalLayout->addWidget(pushButton_new);
+         horizontalLayout->addWidget(pushButton_edit);
+         horizontalLayout->addWidget(pushButton_remove);
+      verticalLayout->addWidget(tableWidget);
+      verticalLayout->addLayout(horizontalLayout);
+
+   retranslateUi();
+   QMetaObject::connectSlotsByName(this);
+}
+
+void YeastDialog::retranslateUi()
+{
+   setWindowTitle(tr("Yeast Database"));
+   pushButton_addToRecipe->setText(tr("Add to Recipe"));
+   pushButton_new->setText(tr("New"));
+   pushButton_edit->setText(QString());
+   pushButton_remove->setText(QString());
+#ifndef QT_NO_TOOLTIP
+   pushButton_addToRecipe->setToolTip(tr("Add selected ingredient to recipe"));
+   pushButton_new->setToolTip(tr("Create new ingredient"));
+   pushButton_edit->setToolTip(tr("Edit selected ingredient"));
+   pushButton_remove->setToolTip(tr("Remove selected ingredient"));
+#endif // QT_NO_TOOLTIP
+}
+
 void YeastDialog::removeYeast()
 {
-   QModelIndexList selected = yeastTableWidget->selectionModel()->selectedIndexes();
+   QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
    QModelIndex translated;
    int row, size, i;
 
@@ -75,7 +137,7 @@ void YeastDialog::removeYeast()
    // proxy model does the heavy lifting, as long as we do the call.
    translated = yeastTableProxy->mapToSource(selected[0]);
    Yeast *yeast = yeastTableModel->getYeast(translated.row());
-   Database::instance().removeYeast(yeast);
+   Database::instance().remove(yeast);
 }
 
 void YeastDialog::addYeast(const QModelIndex& index)
@@ -84,7 +146,7 @@ void YeastDialog::addYeast(const QModelIndex& index)
    
    if( !index.isValid() )
    {
-      QModelIndexList selected = yeastTableWidget->selectionModel()->selectedIndexes();
+      QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
       int row, size, i;
 
       size = selected.size();
@@ -120,7 +182,7 @@ void YeastDialog::addYeast(const QModelIndex& index)
 
 void YeastDialog::editSelected()
 {
-   QModelIndexList selected = yeastTableWidget->selectionModel()->selectedIndexes();
+   QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
    QModelIndex translated; 
 
    int row, size, i;
@@ -156,3 +218,9 @@ void YeastDialog::newYeast()
    yeastEditor->show();
    y->setDisplay(true);
 }
+
+void YeastDialog::filterYeasts(QString searchExpression)
+{
+    yeastTableProxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
+    yeastTableProxy->setFilterFixedString(searchExpression);
+}
