@@ -1,17 +1,21 @@
 /*
- * YeastTableModel.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * YeastTableModel.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
+ * - swstim <swstim@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,8 +30,9 @@
 #include <QComboBox>
 #include <QLineEdit>
 #include <QString>
-
 #include <QVector>
+#include <QHeaderView>
+
 #include "database.h"
 #include "yeast.h"
 #include "YeastTableModel.h"
@@ -36,9 +41,22 @@
 #include "recipe.h"
 
 YeastTableModel::YeastTableModel(QTableView* parent, bool editable)
-: QAbstractTableModel(parent), editable(editable), parentTableWidget(parent), recObs(0)
+   : QAbstractTableModel(parent),
+     editable(editable),
+     _inventoryEditable(false),
+     parentTableWidget(parent),
+     recObs(0)
 {
    yeastObs.clear();
+   setObjectName("yeastTableModel");
+
+   QHeaderView* headerView = parentTableWidget->horizontalHeader();
+   headerView->setContextMenuPolicy(Qt::CustomContextMenu);
+   parentTableWidget->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+   parentTableWidget->setWordWrap(false);
+
+   connect(headerView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(contextMenu(const QPoint&)));
 }
 
 void YeastTableModel::addYeast(Yeast* yeast)
@@ -61,12 +79,6 @@ void YeastTableModel::addYeast(Yeast* yeast)
    connect( yeast, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
    //reset(); // Tell everybody that the table has changed.
    endInsertRows();
-   
-   if(parentTableWidget)
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
 }
 
 void YeastTableModel::observeRecipe(Recipe* rec)
@@ -76,7 +88,7 @@ void YeastTableModel::observeRecipe(Recipe* rec)
       disconnect( recObs, 0, this, 0 );
       removeAll();
    }
-   
+
    recObs = rec;
    if( recObs )
    {
@@ -90,7 +102,7 @@ void YeastTableModel::observeDatabase(bool val)
    if( val )
    {
       observeRecipe(0);
-      
+
       removeAll();
       connect( &(Database::instance()), SIGNAL(newYeastSignal(Yeast*)), this, SLOT(addYeast(Yeast*)) );
       connect( &(Database::instance()), SIGNAL(deletedYeastSignal(Yeast*)), this, SLOT(removeYeast(Yeast*)) );
@@ -107,31 +119,24 @@ void YeastTableModel::addYeasts(QList<Yeast*> yeasts)
 {
    QList<Yeast*>::iterator i;
    QList<Yeast*> tmp;
-   
+
    for( i = yeasts.begin(); i != yeasts.end(); i++ )
    {
       if( !yeastObs.contains(*i) )
          tmp.append(*i);
    }
-   
+
    int size = yeastObs.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       yeastObs.append(tmp);
-      
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
          connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
-      
+
       endInsertRows();
    }
-
-   if( parentTableWidget )
-   {
-      parentTableWidget->resizeColumnsToContents();
-      parentTableWidget->resizeRowsToContents();
-   }
-   
 }
 
 void YeastTableModel::removeYeast(Yeast* yeast)
@@ -145,12 +150,6 @@ void YeastTableModel::removeYeast(Yeast* yeast)
       yeastObs.removeAt(i);
       //reset(); // Tell everybody the table has changed.
       endRemoveRows();
-      
-      if(parentTableWidget)
-      {
-         parentTableWidget->resizeColumnsToContents();
-         parentTableWidget->resizeRowsToContents();
-      }
    }
 }
 
@@ -178,12 +177,12 @@ void YeastTableModel::changed(QMetaProperty prop, QVariant /*val*/)
       i = yeastObs.indexOf(yeastSender);
       if( i < 0 )
          return;
-      
+
       emit dataChanged( QAbstractItemModel::createIndex(i, 0),
                         QAbstractItemModel::createIndex(i, YEASTNUMCOLS-1));
       return;
    }
-   
+
    // See if sender is our recipe.
    Recipe* recSender = qobject_cast<Recipe*>(sender());
    if( recSender && recSender == recObs )
@@ -212,12 +211,12 @@ int YeastTableModel::columnCount(const QModelIndex& /*parent*/) const
 QVariant YeastTableModel::data( const QModelIndex& index, int role ) const
 {
    Yeast* row;
-   unitDisplay unit;
+   Unit::unitDisplay unit;
 
    // Ensure the row is ok.
    if( index.row() >= (int)yeastObs.size() )
    {
-      Brewtarget::log(Brewtarget::WARNING, tr("Bad model index. row = %1").arg(index.row()));
+      Brewtarget::logW(tr("Bad model index. row = %1").arg(index.row()));
       return QVariant();
    }
    else
@@ -226,51 +225,55 @@ QVariant YeastTableModel::data( const QModelIndex& index, int role ) const
    switch( index.column() )
    {
       case YEASTNAMECOL:
-      if( role == Qt::DisplayRole )
+         if( role != Qt::DisplayRole )
+            return QVariant();
+
          return QVariant(row->name());
-      else
-         return QVariant();
       case YEASTTYPECOL:
-      if( role == Qt::DisplayRole )
-         return QVariant(row->typeStringTr());
-      else if( role == Qt::UserRole )
-         return QVariant(row->type());
-      else
-         return QVariant();
+         if( role == Qt::DisplayRole )
+            return QVariant(row->typeStringTr());
+         else if( role == Qt::UserRole )
+            return QVariant(row->type());
+         else
+            return QVariant();
       case YEASTLABCOL:
-      if( role == Qt::DisplayRole )
-         return QVariant(row->laboratory());
-      else
-         return QVariant();
+         if( role == Qt::DisplayRole )
+            return QVariant(row->laboratory());
+         else
+            return QVariant();
       case YEASTPRODIDCOL:
-      if( role == Qt::DisplayRole )
-         return QVariant(row->productID());
-      else
-         return QVariant();
+         if( role == Qt::DisplayRole )
+            return QVariant(row->productID());
+         else
+            return QVariant();
       case YEASTFORMCOL:
-      if( role == Qt::DisplayRole )
-         return QVariant(row->formStringTr());
-      else if( role == Qt::UserRole )
-         return QVariant(row->form());
-      else
-         return QVariant();
+         if( role == Qt::DisplayRole )
+            return QVariant(row->formStringTr());
+         else if( role == Qt::UserRole )
+            return QVariant(row->form());
+         else
+            return QVariant();
+      case YEASTINVENTORYCOL:
+         if( role != Qt::DisplayRole )
+            return QVariant();
+         return QVariant( row->inventory() );
       case YEASTAMOUNTCOL:
-      if( role != Qt::DisplayRole )
-         return QVariant();
+         if( role != Qt::DisplayRole )
+            return QVariant();
 
-      unit  = displayUnit(index.column());
+         unit  = displayUnit(index.column());
 
-      return QVariant( 
-                        Brewtarget::displayAmount( row->amount(), 
-                                                   row->amountIsWeight() ? (Unit*)Units::kilograms : (Unit*)Units::liters, 
-                                                   3, 
-                                                   unit, 
-                                                   noScale 
-                                                 ) 
-                     );
+         return QVariant(
+                           Brewtarget::displayAmount( row->amount(),
+                                                      row->amountIsWeight() ? (Unit*)Units::kilograms : (Unit*)Units::liters,
+                                                      3,
+                                                      unit,
+                                                      Unit::noScale
+                                                   )
+                        );
 
       default :
-         Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(index.column()));
+         Brewtarget::logW(tr("Bad column: %1").arg(index.column()));
          return QVariant();
    }
 }
@@ -287,6 +290,8 @@ QVariant YeastTableModel::headerData( int section, Qt::Orientation orientation,
             return QVariant(tr("Type"));
          case YEASTFORMCOL:
             return QVariant(tr("Form"));
+         case YEASTINVENTORYCOL:
+            return QVariant(tr("Inventory"));
          case YEASTAMOUNTCOL:
             return QVariant(tr("Amount"));
          case YEASTLABCOL:
@@ -294,7 +299,7 @@ QVariant YeastTableModel::headerData( int section, Qt::Orientation orientation,
          case YEASTPRODIDCOL:
              return QVariant(tr("Product ID"));
          default:
-            Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(section));
+            Brewtarget::logW(tr("Bad column: %1").arg(section));
             return QVariant();
       }
    }
@@ -309,6 +314,8 @@ Qt::ItemFlags YeastTableModel::flags(const QModelIndex& index ) const
    {
       case YEASTNAMECOL:
          return Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEnabled;
+      case YEASTINVENTORYCOL:
+         return (Qt::ItemIsEnabled | (_inventoryEditable ? Qt::ItemIsEditable : Qt::NoItemFlags));
       default:
          return Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled |
             Qt::ItemIsEnabled;
@@ -318,7 +325,8 @@ Qt::ItemFlags YeastTableModel::flags(const QModelIndex& index ) const
 bool YeastTableModel::setData( const QModelIndex& index, const QVariant& value, int role )
 {
    Yeast *row;
-   unitDisplay unit;
+   Unit::unitDisplay dispUnit;
+   Unit* unit;
 
    if( index.row() >= (int)yeastObs.size() || role != Qt::EditRole )
       return false;
@@ -328,60 +336,50 @@ bool YeastTableModel::setData( const QModelIndex& index, const QVariant& value,
    switch( index.column() )
    {
       case YEASTNAMECOL:
-         if( value.canConvert(QVariant::String))
-         {
-            row->setName(value.toString());
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::String))
             return false;
+         row->setName(value.toString());
+         break;
       case YEASTLABCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setLaboratory(value.toString());
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::String) )
             return false;
+         row->setLaboratory(value.toString());
+         break;
       case YEASTPRODIDCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            row->setProductID(value.toString());
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::String) )
             return false;
+         row->setProductID(value.toString());
+         break;
       case YEASTTYPECOL:
-         if( value.canConvert(QVariant::Int) )
-         {
-            row->setType(static_cast<Yeast::Type>(value.toInt()));
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::Int) )
             return false;
+         row->setType(static_cast<Yeast::Type>(value.toInt()));
+         break;
       case YEASTFORMCOL:
-         if( value.canConvert(QVariant::Int) )
-         {
-            row->setForm(static_cast<Yeast::Form>(value.toInt()));
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::Int) )
             return false;
+         row->setForm(static_cast<Yeast::Form>(value.toInt()));
+         break;
+      case YEASTINVENTORYCOL:
+         if( ! value.canConvert(QVariant::Int) )
+            return false;
+         row->setInventoryQuanta( value.toInt() );
+         break;
       case YEASTAMOUNTCOL:
-         if( value.canConvert(QVariant::String) )
-         {
-            unit = displayUnit(YEASTAMOUNTCOL);
-            row->setAmount( row->amountIsWeight() ? 
-                            Brewtarget::weightQStringToSI(value.toString(),unit) : 
-                            Brewtarget::volQStringToSI(value.toString(),unit) );
-            return true;
-         }
-         else
+         if( ! value.canConvert(QVariant::String) )
             return false;
+
+         dispUnit = displayUnit(YEASTAMOUNTCOL);
+         unit = row->amountIsWeight() ? (Unit*)Units::kilograms : (Unit*)Units::liters;
+
+         row->setAmount(Brewtarget::qStringToSI(value.toString(),unit,dispUnit));
+         break;
+
       default:
-         Brewtarget::log(Brewtarget::WARNING, tr("Bad column: %1").arg(index.column()));
+         Brewtarget::logW(tr("Bad column: %1").arg(index.column()));
          return false;
    }
+   return true;
 }
 
 Yeast* YeastTableModel::getYeast(unsigned int i)
@@ -389,31 +387,31 @@ Yeast* YeastTableModel::getYeast(unsigned int i)
    return yeastObs[i];
 }
 
-unitDisplay YeastTableModel::displayUnit(int column) const
-{ 
+Unit::unitDisplay YeastTableModel::displayUnit(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noUnit;
+      return Unit::noUnit;
 
-   return (unitDisplay)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::UNIT).toInt();
+   return (Unit::unitDisplay)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::UNIT).toInt();
 }
 
-unitScale YeastTableModel::displayScale(int column) const
-{ 
+Unit::unitScale YeastTableModel::displayScale(int column) const
+{
    QString attribute = generateName(column);
 
    if ( attribute.isEmpty() )
-      return noScale;
+      return Unit::noScale;
 
-   return (unitScale)Brewtarget::option(attribute, QVariant(-1), this, Brewtarget::SCALE).toInt();
+   return (Unit::unitScale)Brewtarget::option(attribute, QVariant(-1), this->objectName(), Brewtarget::SCALE).toInt();
 }
 
 // We need to:
 //   o clear the custom scale if set
 //   o clear any custom unit from the rows
 //      o which should have the side effect of clearing any scale
-void YeastTableModel::setDisplayUnit(int column, unitDisplay displayUnit) 
+void YeastTableModel::setDisplayUnit(int column, Unit::unitDisplay displayUnit)
 {
    // Yeast* row; // disabled per-cell magic
    QString attribute = generateName(column);
@@ -421,21 +419,21 @@ void YeastTableModel::setDisplayUnit(int column, unitDisplay displayUnit)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayUnit,this,Brewtarget::UNIT); 
-   Brewtarget::setOption(attribute,noScale,this,Brewtarget::SCALE);
+   Brewtarget::setOption(attribute,displayUnit,this->objectName(),Brewtarget::UNIT);
+   Brewtarget::setOption(attribute,Unit::noScale,this->objectName(),Brewtarget::SCALE);
 
    /* Disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getYeast(i);
-      row->setDisplayUnit(noUnit);
+      row->setDisplayUnit(Unit::noUnit);
    }
    */
 }
 
 // Setting the scale should clear any cell-level scaling options
-void YeastTableModel::setDisplayScale(int column, unitScale displayScale) 
-{ 
+void YeastTableModel::setDisplayScale(int column, Unit::unitScale displayScale)
+{
    // Yeast* row; //disabled per-cell magic
 
    QString attribute = generateName(column);
@@ -443,13 +441,13 @@ void YeastTableModel::setDisplayScale(int column, unitScale displayScale)
    if ( attribute.isEmpty() )
       return;
 
-   Brewtarget::setOption(attribute,displayScale,this,Brewtarget::SCALE); 
+   Brewtarget::setOption(attribute,displayScale,this->objectName(),Brewtarget::SCALE);
 
    /* disabled cell-specific code
    for (int i = 0; i < rowCount(); ++i )
    {
       row = getYeast(i);
-      row->setDisplayScale(noScale);
+      row->setDisplayScale(Unit::noScale);
    }
    */
 }
@@ -469,6 +467,38 @@ QString YeastTableModel::generateName(int column) const
    return attribute;
 }
 
+void YeastTableModel::contextMenu(const QPoint &point)
+{
+   QObject* calledBy = sender();
+   QHeaderView* hView = qobject_cast<QHeaderView*>(calledBy);
+
+   int selected = hView->logicalIndexAt(point);
+   Unit::unitDisplay currentUnit;
+   Unit::unitScale  currentScale;
+
+   currentUnit  = displayUnit(selected);
+   currentScale = displayScale(selected);
+
+   QMenu* menu;
+   QAction* invoked;
+
+   switch(selected)
+   {
+      case YEASTAMOUNTCOL:
+         menu = Brewtarget::setupMassMenu(parentTableWidget,currentUnit, currentScale, false);
+         break;
+      default:
+         return;
+   }
+
+   invoked = menu->exec(hView->mapToGlobal(point));
+   if ( invoked == 0 )
+      return;
+
+   setDisplayUnit(selected,(Unit::unitDisplay)invoked->data().toInt());
+}
+
+
 //==========================CLASS YeastItemDelegate===============================
 
 YeastItemDelegate::YeastItemDelegate(QObject* parent)
@@ -489,6 +519,7 @@ QWidget* YeastItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
       box->addItem(tr("Wheat"));
       box->addItem(tr("Wine"));
       box->addItem(tr("Champagne"));
+      box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
       return box;
@@ -501,7 +532,8 @@ QWidget* YeastItemDelegate::createEditor(QWidget *parent, const QStyleOptionView
       box->addItem(tr("Dry"));
       box->addItem(tr("Slant"));
       box->addItem(tr("Culture"));
-
+      box->setMinimumWidth(box->minimumSizeHint().width());
+      box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
       return box;
    }
    else
@@ -544,7 +576,7 @@ void YeastItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
    else
    {
       QLineEdit* line = (QLineEdit*)editor;
-      
+
       if ( line->isModified() )
          model->setData(index, line->text(), Qt::EditRole);
    }
