@@ -1,18 +1,19 @@
-/*  
- * brewnote.cpp is part of Brewtarget, written by Mik Firestone
- * (mikfire@gmail.com).   Copyright is given to Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+/*
+ * brewnote.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -31,6 +32,9 @@
 #include "Algorithms.h"
 #include "mashstep.h"
 #include "recipe.h"
+#include "equipment.h"
+#include "mash.h"
+#include "yeast.h"
 
 QHash<QString,QString> BrewNote::tagToProp = BrewNote::tagToPropHash();
 
@@ -104,7 +108,7 @@ void BrewNote::populateNote(Recipe* parent)
    // Since we have the recipe, lets set some defaults The order in which
    // these are done is very specific. Please do not modify them without some
    // serious testing.
-   
+
    // Everything needs volumes of one type or another. But the individual
    // volumes are fairly independent of anything. Do them all first.
    setProjVolIntoBK_l( parent->boilSize_l() );
@@ -117,10 +121,10 @@ void BrewNote::populateNote(Recipe* parent)
    if ( equip )
       setBoilOff_l( equip->evapRate_lHr() * ( parent->boilTime_min()/60));
 
-   sugars = parent->calcTotalPoints(true);
+   sugars = parent->calcTotalPoints();
    setProjPoints(sugars.value("sugar_kg") + sugars.value("sugar_kg_ignoreEfficiency"));
 
-   sugars = parent->calcTotalPoints(false);
+   sugars = parent->calcTotalPoints();
    setProjFermPoints(sugars.value("sugar_kg") + sugars.value("sugar_kg_ignoreEfficiency"));
 
    // Out of the gate, we expect projected to be the measured.
@@ -130,21 +134,27 @@ void BrewNote::populateNote(Recipe* parent)
    if ( mash )
    {
       steps = mash->mashSteps();
-      mStep = steps.at(0);
-      if ( mStep )
+      if ( ! steps.isEmpty() )
       {
-         double endTemp = mStep->endTemp_c() > 0.0 ? mStep->endTemp_c() : mStep->stepTemp_c();
-         setProjStrikeTemp_c(mStep->infuseTemp_c());
+         mStep = steps.at(0);
+         if ( mStep )
+         {
+            double endTemp = mStep->endTemp_c() > 0.0 ? mStep->endTemp_c() : mStep->stepTemp_c();
+            setProjStrikeTemp_c(mStep->infuseTemp_c());
 
-         setMashFinTemp_c(endTemp);
-         setProjMashFinTemp_c(endTemp);
-      }
+            setMashFinTemp_c(endTemp);
+            setProjMashFinTemp_c(endTemp);
+         }
 
-      if ( steps.size() - 2 > 0 )
-      {
-         mStep = steps.at( steps.size() - 2 );
-         setMashFinTemp_c( mStep->endTemp_c());
-         setProjMashFinTemp_c( mStep->endTemp_c());
+         if ( steps.size() > 2 )
+         {
+            // NOTE: Qt will complain that steps.size()-2 is always positive,
+            // and therefore the internal assert that the index is positive is
+            // bunk. This is OK, as we just checked that we will not underflow.
+            mStep = steps.at( steps.size() - 2 );
+            setMashFinTemp_c( mStep->endTemp_c());
+            setProjMashFinTemp_c( mStep->endTemp_c());
+         }
       }
    }
 
@@ -179,10 +189,10 @@ void BrewNote::recalculateEff(Recipe* parent)
 
    QHash<QString,double> sugars;
 
-   sugars = parent->calcTotalPoints(true);
+   sugars = parent->calcTotalPoints();
    setProjPoints(sugars.value("sugar_kg") + sugars.value("sugar_kg_ignoreEfficiency"));
 
-   sugars = parent->calcTotalPoints(false);
+   sugars = parent->calcTotalPoints();
    setProjFermPoints(sugars.value("sugar_kg") + sugars.value("sugar_kg_ignoreEfficiency"));
 
    calculateEffIntoBK_pct();
@@ -211,41 +221,13 @@ void BrewNote::setNotes(QString const& var, bool notify)
    set("notes", "notes", var, notify);
 }
 
-double BrewNote::translateSG(QString qstr)
-{
-   double var;
-   QString unit;
-   QRegExp numUnit;
-
-   // Try to make some guesses about what is there.
-   QString decimal = QRegExp::escape( QLocale::system().decimalPoint());
-   QString grouping = QRegExp::escape(QLocale::system().groupSeparator());
-
-   numUnit.setPattern("((?:\\d+" + grouping + ")?\\d+(?:" + decimal + "\\d+)?|" + decimal + "\\d+)\\s*(\\w+)?");
-   numUnit.setCaseSensitivity(Qt::CaseInsensitive);
-
-   if ( qstr.contains(numUnit) )
-   {
-      var  = numUnit.capturedTexts()[1].toDouble();
-      unit = numUnit.capturedTexts()[2];
-   }
-   else 
-      var = qstr.toDouble();
-
-
-   if ( unit.contains("p", Qt::CaseInsensitive) || var > 1.2)
-      return Algorithms::Instance().PlatoToSG_20C20C(var);
-
-   return var;
-}
-
 void BrewNote::setLoading(bool flag) { loading = flag; }
 
 // These five items cause the calculated fields to change. I should do this
 // with signals/slots, likely, but the *only* slot for the signal will be
 // the brewnote.
 void BrewNote::setSg(double var)
-{ 
+{
    set("sg", "sg", var);
 
    if ( loading )
@@ -256,7 +238,7 @@ void BrewNote::setSg(double var)
 }
 
 void BrewNote::setVolumeIntoBK_l(double var)
-{ 
+{
    set("volumeIntoBK_l", "volume_into_bk", var);
 
    if ( loading )
@@ -268,7 +250,7 @@ void BrewNote::setVolumeIntoBK_l(double var)
 }
 
 void BrewNote::setOg(double var)
-{ 
+{
    set("og", "og", var);
 
    if ( loading )
@@ -280,7 +262,7 @@ void BrewNote::setOg(double var)
 }
 
 void BrewNote::setVolumeIntoFerm_l(double var)
-{ 
+{
    set("volumeIntoFerm_l", "volume_into_fermenter", var);
 
    if ( loading )
@@ -290,7 +272,7 @@ void BrewNote::setVolumeIntoFerm_l(double var)
 }
 
 void BrewNote::setFg(double var)
-{ 
+{
    set("fg", "fg", var);
 
    if ( loading )
@@ -300,39 +282,39 @@ void BrewNote::setFg(double var)
 }
 
 // This one is a bit of an odd ball. We need to convert to pure glucose points
-// before we store it in the database. 
+// before we store it in the database.
 void BrewNote::setProjPoints(double var)
-{ 
+{
    double convertPnts;
    double plato, total_g;
 
    if ( loading )
       convertPnts = var;
    else
-   { 
-      plato = Algorithms::Instance().getPlato(var, projVolIntoBK_l());
-      total_g = Algorithms::Instance().PlatoToSG_20C20C( plato );
+   {
+      plato = Algorithms::getPlato(var, projVolIntoBK_l());
+      total_g = Algorithms::PlatoToSG_20C20C( plato );
       convertPnts = (total_g - 1.0 ) * 1000;
    }
 
-   set("projPoints", "projected_points", convertPnts); 
+   set("projPoints", "projected_points", convertPnts);
 }
 
 void BrewNote::setProjFermPoints(double var)
-{ 
+{
    double convertPnts;
    double plato, total_g;
 
    if ( loading )
       convertPnts = var;
    else
-   { 
-      plato = Algorithms::Instance().getPlato(var, projVolIntoFerm_l());
-      total_g = Algorithms::Instance().PlatoToSG_20C20C( plato );
+   {
+      plato = Algorithms::getPlato(var, projVolIntoFerm_l());
+      total_g = Algorithms::PlatoToSG_20C20C( plato );
       convertPnts = (total_g - 1.0 ) * 1000;
    }
 
-   set("projPoints", "projected_ferm_points", convertPnts); 
+   set("projPoints", "projected_ferm_points", convertPnts);
 }
 
 void BrewNote::setABV(double var)               { set("abv", "abv", var); }
@@ -358,37 +340,37 @@ void BrewNote::setBoilOff_l(double var)         { set("boilOff_l", "boil_off", v
 // Getters
 QDateTime BrewNote::brewDate()      const { return QDateTime::fromString(get("brewDate").toString(),Qt::ISODate); }
 QString BrewNote::brewDate_str()    const { return get("brewDate").toString(); }
-QString BrewNote::brewDate_short()  const { return brewDate().toString("yyyy-MM-dd"); }
 QDateTime BrewNote::fermentDate()   const { return QDateTime::fromString(get("fermentDate").toString(),Qt::ISODate); }
 QString BrewNote::fermentDate_str() const { return get("fermentDate").toString(); }
 QString BrewNote::fermentDate_short() const { return fermentDate().toString("yyyy-MM-dd"); }
 QString BrewNote::notes()           const { return get("notes").toString(); }
+QString BrewNote::brewDate_short()  const { return Brewtarget::displayDateUserFormated(brewDate().date()); }
 
-double BrewNote::sg() const              { return get("sg").toDouble(); }
+double BrewNote::sg() const                { return get("sg").toDouble(); }
 double BrewNote::abv() const               { return get("abv").toDouble(); }
 double BrewNote::volumeIntoBK_l() const    { return get("volume_into_bk").toDouble(); }
 double BrewNote::effIntoBK_pct() const     { return get("eff_into_bk").toDouble(); }
 double BrewNote::brewhouseEff_pct() const  { return get("brewhouse_eff").toDouble(); }
 double BrewNote::strikeTemp_c() const      { return get("strike_temp").toDouble(); }
 double BrewNote::mashFinTemp_c() const     { return get("mash_final_temp").toDouble(); }
-double BrewNote::og() const              { return get("og").toDouble(); }
+double BrewNote::og() const                { return get("og").toDouble(); }
 double BrewNote::volumeIntoFerm_l() const  { return get("volume_into_fermenter").toDouble(); }
 double BrewNote::postBoilVolume_l() const  { return get("post_boil_volume").toDouble(); }
 double BrewNote::pitchTemp_c() const       { return get("pitch_temp").toDouble(); }
-double BrewNote::fg() const              { return get("fg").toDouble(); }
+double BrewNote::fg() const                { return get("fg").toDouble(); }
 double BrewNote::finalVolume_l() const     { return get("final_volume").toDouble(); }
-double BrewNote::projBoilGrav() const    { return get("projected_boil_grav").toDouble(); }
+double BrewNote::projBoilGrav() const      { return get("projected_boil_grav").toDouble(); }
 double BrewNote::projVolIntoBK_l() const   { return get("projected_vol_into_bk").toDouble(); }
 double BrewNote::projStrikeTemp_c() const  { return get("projected_strike_temp").toDouble(); }
 double BrewNote::projMashFinTemp_c() const { return get("projected_mash_fin_temp").toDouble(); }
-double BrewNote::projOg() const          { return get("projected_og").toDouble(); }
+double BrewNote::projOg() const            { return get("projected_og").toDouble(); }
 double BrewNote::projVolIntoFerm_l() const { return get("projected_vol_into_ferm").toDouble(); }
-double BrewNote::projFg() const          { return get("projected_fg").toDouble(); }
-double BrewNote::projEff_pct() const         { return get("projected_eff").toDouble(); }
-double BrewNote::projABV_pct() const         { return get("projected_abv").toDouble(); }
-double BrewNote::projPoints() const      { return get("projected_points").toDouble(); }
-double BrewNote::projFermPoints() const      { return get("projected_ferm_points").toDouble(); }
-double BrewNote::projAtten() const       { return get("projected_atten").toDouble(); }
+double BrewNote::projFg() const            { return get("projected_fg").toDouble(); }
+double BrewNote::projEff_pct() const       { return get("projected_eff").toDouble(); }
+double BrewNote::projABV_pct() const       { return get("projected_abv").toDouble(); }
+double BrewNote::projPoints() const        { return get("projected_points").toDouble(); }
+double BrewNote::projFermPoints() const    { return get("projected_ferm_points").toDouble(); }
+double BrewNote::projAtten() const         { return get("projected_atten").toDouble(); }
 double BrewNote::boilOff_l() const         { return get("boil_off").toDouble(); }
 
 int BrewNote::key() const                  { return _key; }
@@ -414,7 +396,7 @@ double BrewNote::calculateEffIntoBK_pct()
 
    effIntoBK = actualPoints/maxPoints * 100;
    setEffIntoBK_pct(effIntoBK);
-   
+
    return effIntoBK;
 }
 
@@ -422,7 +404,7 @@ double BrewNote::calculateEffIntoBK_pct()
 // will be.
 double BrewNote::calculateOg()
 {
-   double cOG; 
+   double cOG;
    double points, expectedVol, actualVol;
 
    points = (sg()-1) * 1000;
@@ -435,7 +417,7 @@ double BrewNote::calculateOg()
       return 0.0;
    }
 
-   cOG = 1+ ((points * actualVol / expectedVol) / 1000); 
+   cOG = 1+ ((points * actualVol / expectedVol) / 1000);
    setProjOg(cOG);
 
    return cOG;
@@ -464,7 +446,7 @@ double BrewNote::calculateABV_pct()
    double estFg;
 
    // This looks weird, but the math works. (Yes, I am showing my work)
-   // 1 + [(og-1) * 1000 * (1.0 - %/100)] / 1000  = 
+   // 1 + [(og-1) * 1000 * (1.0 - %/100)] / 1000  =
    // 1 + [(og - 1) * (1.0 - %/100)]
    estFg = 1 + ((og()-1.0)*(1.0 - atten_pct/100.0));
 
@@ -480,7 +462,7 @@ double BrewNote::calculateActualABV_pct()
 
    abv = (og() - fg()) * 130;
    setABV(abv);
-   
+
    return abv;
 }
 
