@@ -1,18 +1,20 @@
-/*  
- * brewnote.h is part of Brewtarget, written by Mik Firestone
- * (mikfire@gmail.com).   Copyright is given to Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+/*
+ * brewnote.h is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Jeff Bailey <skydvr38@verizon.net>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -26,11 +28,6 @@
 #include <QStringList>
 #include <QDate>
 
-#include "equipment.h"
-#include "mash.h"
-#include "mashstep.h"
-#include "yeast.h"
-
 #include "BeerXMLElement.h"
 
 // Forward declarations;
@@ -177,16 +174,6 @@ public:
    double projFermPoints() const;
    double projAtten() const;
    
-   /*! Convert a string that may be either "1.040" or "10 P" for example.
-    * If the user has appended a "P" (case insensitive, with or without a space),
-    * the gravity reading will be assumed to be in plato/brix.
-    * If there is no unit, and the value is < 2.0, it will be assumed to be a
-    * specific gravity.
-    * If there is no unit and the value is greater than 2.0, it will be assumed
-    * to be a plato/brix
-    */
-   static double translateSG(QString qstr);
-
 signals:
    void brewDateChanged(const QDateTime&);
 
@@ -202,6 +189,8 @@ private:
    static QHash<QString,QString> tagToProp;
 };
 
+Q_DECLARE_METATYPE( QList<BrewNote*> )
+
 inline bool BrewNotePtrLt( BrewNote* lhs, BrewNote* rhs)
 {
    return *lhs < *rhs;
