@@ -1,17 +1,21 @@
 /*
- * fermentable.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * fermentable.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,6 +39,7 @@ QHash<QString,QString> Fermentable::tagToPropHash()
    // NOTE: since type is actually stored as a string (not integer), have to handle separately.
    //propHash["TYPE"] = "type";
    propHash["AMOUNT"] = "amount_kg";
+   propHash["INVENTORY"] = "inventory";
    propHash["YIELD"] = "yield_pct";
    propHash["COLOR"] = "color_srm";
    propHash["ADD_AFTER_BOIL"] = "addAfterBoil";
@@ -207,6 +212,30 @@ void Fermentable::setDefaults()
 // Get
 const QString Fermentable::name() const { return get("name").toString(); }
 const Fermentable::Type Fermentable::type() const { return static_cast<Fermentable::Type>(types.indexOf(get("ftype").toString())); }
+const Fermentable::AdditionMethod Fermentable::additionMethod() const
+{
+   Fermentable::AdditionMethod additionMethod;
+   if(isMashed())
+      additionMethod = Fermentable::Mashed;
+   else
+   {
+      if(type() == Fermentable::Grain)
+         additionMethod = Fermentable::Steeped;
+      else
+         additionMethod = Fermentable::Not_Mashed;
+   }
+   return additionMethod;
+}
+const Fermentable::AdditionTime Fermentable::additionTime() const
+{
+   Fermentable::AdditionTime additionTime;
+   if(addAfterBoil())
+      additionTime = Fermentable::Late;
+   else
+      additionTime = Fermentable::Normal;
+
+   return additionTime;
+}
 const QString Fermentable::typeString() const
 {
    return types.at(type());
@@ -216,25 +245,60 @@ const QString Fermentable::typeStringTr() const
    static QStringList typesTr = QStringList () << QObject::tr("Grain") << QObject::tr("Sugar") << QObject::tr("Extract") << QObject::tr("Dry Extract") << QObject::tr("Adjunct");
    return typesTr.at(type());
 }
-double Fermentable::amount_kg() const { return get("amount").toDouble(); }
-double Fermentable::yield_pct() const { return get("yield").toDouble(); }
-double Fermentable::color_srm() const { return get("color").toDouble(); }
+
+const QString Fermentable::additionMethodStringTr() const
+{
+    QString retString;
+
+    if(isMashed())
+       retString = tr("Mashed");
+    else
+    {
+       if(type() == Fermentable::Grain)
+          retString = tr("Steeped");
+       else
+          retString = tr("Not mashed");
+    }
+    return retString;
+}
+
+const QString Fermentable::additionTimeStringTr() const
+{
+    QString retString;
+
+    if(addAfterBoil())
+       retString = tr("Late");
+    else
+       retString = tr("Normal");
+
+    return retString;
+}
+
+double Fermentable::amount_kg()              const { return get("amount").toDouble(); }
+double Fermentable::yield_pct()              const { return get("yield").toDouble(); }
+double Fermentable::color_srm()              const { return get("color").toDouble(); }
+double Fermentable::coarseFineDiff_pct()     const { return get("coarse_fine_diff").toDouble(); }
+double Fermentable::moisture_pct()           const { return get("moisture").toDouble(); }
+double Fermentable::diastaticPower_lintner() const { return get("diastatic_power").toDouble(); }
+double Fermentable::protein_pct()            const { return get("protein").toDouble(); }
+double Fermentable::maxInBatch_pct()         const { return get("max_in_batch").toDouble(); }
+double Fermentable::ibuGalPerLb()            const { return get("ibu_gal_per_lb").toDouble(); }
+
+// inventory must be handled separately, to my great annoyance
+double Fermentable::inventory() const 
+{ 
+   return getInventory("amount").toDouble();
+}
 
 bool Fermentable::addAfterBoil() const { return get("add_after_boil").toBool(); }
 const QString Fermentable::origin() const { return get("origin").toString(); }
 const QString Fermentable::supplier() const { return get("supplier").toString(); }
 const QString Fermentable::notes() const { return get("notes").toString(); }
-double Fermentable::coarseFineDiff_pct() const { return get("coarse_fine_diff").toDouble(); }
-double Fermentable::moisture_pct() const { return get("moisture").toDouble(); }
-double Fermentable::diastaticPower_lintner() const { return get("diastatic_power").toDouble(); }
-double Fermentable::protein_pct() const { return get("protein").toDouble(); }
-double Fermentable::maxInBatch_pct() const { return get("max_in_batch").toDouble(); }
 bool Fermentable::recommendMash() const { return get("recommend_mash").toBool(); }
 bool Fermentable::isMashed() const { return get("is_mashed").toBool(); }
 bool Fermentable::isExtract() { return ((type() == Extract) || (type() == Dry_Extract)); }
 bool Fermentable::isSugar() { return (type() == Sugar); }
 
-double Fermentable::ibuGalPerLb() const { return get("ibu_gal_per_lb").toDouble(); }
 
 double Fermentable::equivSucrose_kg() const
 {
@@ -259,11 +323,28 @@ void Fermentable::setName( const QString& str )
    set("name", "name", str);
    emit changedName(str);
 }
+
 void Fermentable::setType( Type t )
 {
    set("type", "ftype", types.at(t));
 }
 
+void Fermentable::setAdditionMethod( Fermentable::AdditionMethod m )
+{
+   if( m == Fermentable::Mashed )
+      setIsMashed(true);
+   else
+      setIsMashed(false);
+}
+
+void Fermentable::setAdditionTime( Fermentable::AdditionTime t )
+{
+   if( t == Fermentable::Late )
+      setAddAfterBoil(true);
+   else
+      setAddAfterBoil(false);
+}
+
 void Fermentable::setAmount_kg( double num )
 {
    if( num < 0.0 )
@@ -276,6 +357,18 @@ void Fermentable::setAmount_kg( double num )
       set("amount_kg", "amount", num);
    }
 }
+void Fermentable::setInventoryAmount( double num )
+{
+   if( num < 0.0 )
+   {
+      Brewtarget::logW( QString("Fermentable: negative inventory: %1").arg(num) );
+      return;
+   }
+   else
+   {
+      setInventory("inventory", "amount", num);
+   }
+}
 void Fermentable::setYield_pct( double num )
 {
    if( num >= 0.0 && num <= 100.0 )
