@@ -1,22 +1,25 @@
 /*
- * hop.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * hop.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include <QDomElement>
 #include <QDomText>
 #include <QObject>
@@ -35,6 +38,7 @@ QHash<QString,QString> Hop::tagToPropHash()
    propHash["NAME"] = "name";
    propHash["ALPHA"] = "alpha_pct";
    propHash["AMOUNT"] = "amount_kg";
+   propHash["INVENTORY"] = "inventory";
    //propHash["USE"] = "use";
    propHash["TIME"] = "time_min";
    propHash["NOTES"] = "notes";
@@ -141,6 +145,18 @@ void Hop::setAmount_kg( double num )
       set("amount_kg", "amount", num);
    }
 }
+void Hop::setInventoryAmount( double num )
+{
+   if( num < 0.0 )
+   {
+      Brewtarget::logW( QString("Hop: inventory < 0: %1").arg(num) );
+      return;
+   }
+   else
+   {
+      setInventory("inventory", "amount", num);
+   }
+}
 
 void Hop::setUse(Use u)
 {
@@ -268,30 +284,33 @@ void Hop::setMyrcene_pct( double num )
 
 //============================="GET" METHODS====================================
 
-const QString Hop::name() const
-{
-   return get("name").toString();
-}
+const QString Hop::name() const { return get("name").toString(); }
+Hop::Use Hop::use() const { return static_cast<Hop::Use>(uses.indexOf(get("use").toString())); }
+const QString Hop::useString() const { return get("use").toString(); }
+Hop::Form Hop::form() const { return static_cast<Hop::Form>(forms.indexOf(get("form").toString())); }
+const QString Hop::notes() const { return get("notes").toString(); }
+Hop::Type Hop::type() const { return static_cast<Hop::Type>(types.indexOf(get("htype").toString())); }
+const QString Hop::typeString() const { return get("htype").toString(); }
+const QString Hop::formString() const { return get("form").toString(); }
+const QString Hop::origin() const { return get("origin").toString(); }
+const QString Hop::substitutes() const { return get("substitutes").toString(); }
 
-double Hop::alpha_pct() const
-{
-   return get("alpha").toDouble();
-}
+double Hop::alpha_pct()          const { return get("alpha").toDouble(); }
+double Hop::amount_kg()          const { return get("amount").toDouble(); }
+double Hop::time_min()           const { return get("time").toDouble(); }
+double Hop::beta_pct()           const { return get("beta").toDouble(); }
+double Hop::hsi_pct()            const { return get("hsi").toDouble(); }
+double Hop::humulene_pct()       const { return get("humulene").toDouble(); }
+double Hop::caryophyllene_pct()  const { return get("caryophyllene").toDouble(); }
+double Hop::cohumulone_pct()     const { return get("cohumulone").toDouble(); }
+double Hop::myrcene_pct()        const { return get("myrcene").toDouble(); }
 
-double Hop::amount_kg() const
+// inventory still must be handled separately, and I'm still annoyed.
+double Hop::inventory() const
 {
-   return get("amount").toDouble();
-}
-
-Hop::Use Hop::use() const
-{
-   return static_cast<Hop::Use>(uses.indexOf(get("use").toString()));
-}
-
-const QString Hop::useString() const
-{
-   return get("use").toString();
+   return getInventory("amount").toDouble();
 }
+ 
 
 const QString Hop::useStringTr() const
 {
@@ -299,84 +318,15 @@ const QString Hop::useStringTr() const
    return usesTr.at(use());
 }
 
-double Hop::time_min() const
-{
-   return get("time").toDouble();
-}
-
-const QString Hop::notes() const
-{
-   return get("notes").toString();
-}
-
-Hop::Type Hop::type() const
-{
-   return static_cast<Hop::Type>(types.indexOf(get("htype").toString()));
-}
-
-const QString Hop::typeString() const
-{
-   return get("htype").toString();
-}
-
 const QString Hop::typeStringTr() const
 {
    static QStringList typesTr = QStringList() << tr("Bittering") << tr("Aroma") << tr("Both");
    return typesTr.at(type());
 }
 
-Hop::Form Hop::form() const
-{
-   return static_cast<Hop::Form>(forms.indexOf(get("form").toString()));
-}
-
-const QString Hop::formString() const
-{
-   return get("form").toString();
-}
-
 const QString Hop::formStringTr() const
 {
    static QStringList formsTr = QStringList() << tr("Leaf") << tr("Pellet") << tr("Plug");
    return formsTr.at(form());
 }
 
-double Hop::beta_pct() const
-{
-   return get("beta").toDouble();
-}
-
-double Hop::hsi_pct() const
-{
-   return get("hsi").toDouble();
-}
-
-const QString Hop::origin() const
-{
-   return get("origin").toString();
-}
-
-const QString Hop::substitutes() const
-{
-   return get("substitutes").toString();
-}
-
-double Hop::humulene_pct() const
-{
-   return get("humulene").toDouble();
-}
-
-double Hop::caryophyllene_pct() const
-{
-   return get("caryophyllene").toDouble();
-}
-
-double Hop::cohumulone_pct() const
-{
-   return get("cohumulone").toDouble();
-}
-
-double Hop::myrcene_pct() const
-{
-   return get("myrcene").toDouble();
-}
