@@ -1,17 +1,18 @@
 /*
- * mashstep.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * mashstep.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -236,65 +237,23 @@ void MashStep::setDecoctionAmount_l(double var)
 }
 
 //============================="GET" METHODS====================================
-QString MashStep::name() const
-{
-   return get("name").toString();
-}
 
-double MashStep::infuseTemp_c() const
-{
-   return get("infuse_temp").toDouble();
-}
+QString MashStep::name() const { return get("name").toString(); }
 
-MashStep::Type MashStep::type() const
-{
-   return static_cast<MashStep::Type>(types.indexOf(get("mstype").toString()));
-}
+MashStep::Type MashStep::type()        const { return static_cast<MashStep::Type>(types.indexOf(get("mstype").toString())); }
 
-const QString MashStep::typeString() const
-{
-   return get("mstype").toString();
-}
+const QString MashStep::typeString()   const { return get("mstype").toString(); }
+const QString MashStep::typeStringTr() const { return typesTr.at(type()); }
 
-const QString MashStep::typeStringTr() const
-{
-   return typesTr.at(type());
-}
+double MashStep::infuseTemp_c()        const { return get("infuse_temp").toDouble(); }
+double MashStep::infuseAmount_l()      const { return get("infuse_amount").toDouble(); }
+double MashStep::stepTemp_c()          const { return get("step_temp").toDouble(); }
+double MashStep::stepTime_min()        const { return get("step_time").toDouble(); }
+double MashStep::rampTime_min()        const { return get("ramp_time").toDouble(); }
+double MashStep::endTemp_c()           const { return get("end_temp").toDouble(); }
+double MashStep::decoctionAmount_l()   const { return get("decoction_amount").toDouble(); }
 
-double MashStep::infuseAmount_l() const
-{
-   return get("infuse_amount").toDouble();
-}
-
-double MashStep::stepTemp_c() const
-{
-   return get("step_temp").toDouble();
-}
-
-double MashStep::stepTime_min() const
-{
-   return get("step_time").toDouble();
-}
-
-double MashStep::rampTime_min() const
-{
-   return get("ramp_time").toDouble();
-}
-
-double MashStep::endTemp_c() const
-{
-   return get("end_temp").toDouble();
-}
-
-double MashStep::decoctionAmount_l() const
-{
-   return get("decoction_amount").toDouble();
-}
-
-int MashStep::stepNumber() const
-{
-   return get("step_number").toInt();
-}
+int MashStep::stepNumber()             const { return get("step_number").toInt(); }
 
 bool MashStep::isValidType( const QString &str ) const
 {
