@@ -1,17 +1,20 @@
 /*
- * misc.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * misc.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - mik firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,6 +32,7 @@
 
 QStringList Misc::uses = QStringList() << "Boil" << "Mash" << "Primary" << "Secondary" << "Bottling";
 QStringList Misc::types = QStringList() << "Spice" << "Fining" << "Water Agent" << "Herb" << "Flavor" << "Other";
+QStringList Misc::amountTypes = QStringList() << "Weight" << "Volume";
 QHash<QString,QString> Misc::tagToProp = Misc::tagToPropHash();
 
 QHash<QString,QString> Misc::tagToPropHash()
@@ -40,6 +44,7 @@ QHash<QString,QString> Misc::tagToPropHash()
    propHash["TIME"] = "time";
    propHash["AMOUNT"] = "amount";
    propHash["AMOUNT_IS_WEIGHT"] = "amountIsWeight";
+   propHash["INVENTORY"] = "inventory";
    propHash["USE_FOR"] = "useFor";
    propHash["NOTES"] = "notes";
    return propHash;
@@ -71,7 +76,7 @@ const QString Misc::typeString() const
 
 const QString Misc::typeStringTr() const
 {
-   QStringList typesTr = QStringList() << QObject::tr("Spice") << QObject::tr("Fining") << QObject::tr("Water Agent") << QObject::tr("Herb") << QObject::tr("Flavor") << QObject::tr("Other");
+   QStringList typesTr = QStringList() << tr("Spice") << tr("Fining") << tr("Water Agent") << tr("Herb") << tr("Flavor") << tr("Other");
    return typesTr.at(type());
 }
 
@@ -87,33 +92,37 @@ const QString Misc::useString() const
 
 const QString Misc::useStringTr() const
 {
-   QStringList usesTr = QStringList() << QObject::tr("Boil") << QObject::tr("Mash") << QObject::tr("Primary") << QObject::tr("Secondary") << QObject::tr("Bottling");
+   QStringList usesTr = QStringList() << tr("Boil") << tr("Mash") << tr("Primary") << tr("Secondary") << tr("Bottling");
    return usesTr.at(use());
 }
 
-double Misc::amount() const
+Misc::AmountType Misc::amountType() const
 {
-   return get("amount").toDouble();
+   return amountIsWeight() ? AmountType_Weight : AmountType_Volume;
 }
 
-double Misc::time() const
+const QString Misc::amountTypeString() const
 {
-   return get("time").toDouble();
+   return amountTypes.at(amountType());
 }
 
-bool Misc::amountIsWeight() const
+const QString Misc::amountTypeStringTr() const
 {
-   return get("amount_is_weight").toBool();
+   QStringList amountTypesTr = QStringList() << tr("Weight") << tr("Volume");
+   return amountTypesTr.at(amountType());
 }
 
-QString Misc::useFor() const
-{
-   return get("use_for").toString();
-}
+double Misc::amount()    const { return get("amount").toDouble(); }
+double Misc::time()      const { return get("time").toDouble(); }
 
-QString Misc::notes() const
-{
-   return get("notes").toString();
+bool Misc::amountIsWeight() const { return get("amount_is_weight").toBool(); }
+
+QString Misc::useFor() const { return get("use_for").toString(); }
+QString Misc::notes() const { return get("notes").toString(); }
+
+double Misc::inventory() const 
+{ 
+   return getInventory("amount").toDouble();
 }
 
 //============================"SET" METHODS=====================================
@@ -133,6 +142,11 @@ void Misc::setUse( Use u )
    set( "use", "use", uses.at(u) );
 }
 
+void Misc::setAmountType( AmountType t )
+{
+   setAmountIsWeight(t == AmountType_Weight ? true : false);
+}
+
 void Misc::setAmount( double var )
 {
    if( var < 0.0 )
@@ -141,6 +155,14 @@ void Misc::setAmount( double var )
       set( "amount", "amount", var );
 }
 
+void Misc::setInventoryAmount( double var )
+{
+   if( var < 0.0 )
+      Brewtarget::logW( QString("Misc: inventory < 0: %1").arg(var) );
+   else
+      setInventory("inventory", "amount", var );
+}
+
 void Misc::setTime( double var )
 {
    if( var < 0.0 )
