@@ -1,17 +1,20 @@
 /*
- * recipe.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * recipe.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2015
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -227,23 +230,23 @@ QVector<PreInstruction> Recipe::mashInstructions(double timeRemaining, double to
       if( mstep->type() == MashStep::Infusion )
       {
          str = tr("Add %1 water at %2 to mash to bring it to %3.")
-               .arg(Brewtarget::displayAmount(mstep->infuseAmount_l(), Units::liters))
-               .arg(Brewtarget::displayAmount(mstep->infuseTemp_c(), Units::celsius))
-               .arg(Brewtarget::displayAmount(mstep->stepTemp_c(), Units::celsius));
+               .arg(Brewtarget::displayAmount(mstep->infuseAmount_l(), "mashStepTableModel", "infuseAmount_l", Units::liters))
+               .arg(Brewtarget::displayAmount(mstep->infuseTemp_c(), "mashStepTableModel", "infuseTemp_c", Units::celsius))
+               .arg(Brewtarget::displayAmount(mstep->stepTemp_c(), "mashStepTableModel", "stepTemp_c", Units::celsius));
          totalWaterAdded_l += mstep->infuseAmount_l();
       }
       else if( mstep->type() == MashStep::Temperature )
       {
-         str = tr("Heat mash to %1.").arg(Brewtarget::displayAmount(mstep->stepTemp_c(), Units::celsius));
+         str = tr("Heat mash to %1.").arg(Brewtarget::displayAmount(mstep->stepTemp_c(), "mashStepTableModel", "stepTemp_c", Units::celsius));
       }
       else if( mstep->type() == MashStep::Decoction )
       {
          str = tr("Bring %1 of the mash to a boil and return to the mash tun to bring it to %2.")
-               .arg(Brewtarget::displayAmount(mstep->decoctionAmount_l(), Units::liters))
-               .arg(Brewtarget::displayAmount(mstep->stepTemp_c(), Units::celsius));
+               .arg(Brewtarget::displayAmount(mstep->decoctionAmount_l(), "mashStepTableModel", "decoctionAmount_l", Units::liters))
+               .arg(Brewtarget::displayAmount(mstep->stepTemp_c(), "mashStepTableModel", "stepTemp_c", Units::celsius));
       }
 
-      str += tr(" Hold for %1.").arg(Brewtarget::displayAmount(mstep->stepTime_min(), Units::minutes));
+      str += tr(" Hold for %1.").arg(Brewtarget::displayAmount(mstep->stepTime_min(), "mashStepTableModel", "stepTime_min", Units::minutes));
 
       preins.push_back(PreInstruction(str, QString("%1 - %2").arg(mstep->typeStringTr()).arg(mstep->name()),
                   timeRemaining));
@@ -283,9 +286,9 @@ QVector<PreInstruction> Recipe::hopSteps(Hop::Use type)
             str = tr("Use %1 %2 for %3");
          }
 
-         str = str.arg(Brewtarget::displayAmount(hop->amount_kg(), Units::kilograms))
+         str = str.arg(Brewtarget::displayAmount(hop->amount_kg(), "hopTable", "amount_kg", Units::kilograms))
                   .arg(hop->name())
-                  .arg(Brewtarget::displayAmount(hop->time_min(), Units::minutes));
+                  .arg(Brewtarget::displayAmount(hop->time_min(),"hopTable", "time",  Units::minutes));
 
          preins.push_back(PreInstruction(str, tr("Hop addition"), hop->time_min()));
       }
@@ -297,6 +300,7 @@ QVector<PreInstruction> Recipe::miscSteps(Misc::Use type)
 {
    QVector<PreInstruction> preins;
    QString str;
+   Unit* kindOf;
    unsigned int i;
    int size;
 
@@ -323,9 +327,10 @@ QVector<PreInstruction> Recipe::miscSteps(Misc::Use type)
             str = tr("Use %1 %2 for %3.");
          }
 
-         str = str .arg(Brewtarget::displayAmount(misc->amount(), ((misc->amountIsWeight()) ? (Unit*)(Units::kilograms) : (Unit*)(Units::liters) )))
+         kindOf = misc->amountIsWeight() ? (Unit*)Units::kilograms : (Unit*)Units::liters;
+         str = str .arg(Brewtarget::displayAmount(misc->amount(), "miscTableModel", "amount", kindOf))
                    .arg(misc->name())
-                   .arg(Brewtarget::displayAmount(misc->time(), Units::minutes));
+                   .arg(Brewtarget::displayAmount(misc->time(), "miscTableModel", "time", Units::minutes));
 
          preins.push_back(PreInstruction(str, tr("Misc addition"), misc->time()));
       }
@@ -368,13 +373,13 @@ Instruction* Recipe::topOffIns()
    {
       wortInBoil_l = wortFromMash_l() - e->lauterDeadspace_l();
       str = tr("You should now have %1 wort.")
-         .arg(Brewtarget::displayAmount( wortInBoil_l, Units::liters));
+         .arg(Brewtarget::displayAmount( wortInBoil_l, "tab_recipe", "boilSize_l", Units::liters));
       if ( e->topUpKettle_l() != 0 )
       {
          wortInBoil_l += e->topUpKettle_l();
          tmp = tr(" Add %1 water to the kettle, bringing pre-boil volume to %2.")
-            .arg(Brewtarget::displayAmount(e->topUpKettle_l(), Units::liters))
-            .arg(Brewtarget::displayAmount(wortInBoil_l, Units::liters));
+            .arg(Brewtarget::displayAmount(e->topUpKettle_l(), "tab_recipe", "boilSize_l",  Units::liters))
+            .arg(Brewtarget::displayAmount(wortInBoil_l, "tab_recipe", "boilSize_l",  Units::liters));
 
          str += tmp;
 
@@ -432,7 +437,7 @@ PreInstruction Recipe::boilFermentablesPre(double timeRemaining)
        continue;
 
      str += QString("%1 %2, ")
-          .arg(Brewtarget::displayAmount(ferm->amount_kg(), Units::kilograms))
+          .arg(Brewtarget::displayAmount(ferm->amount_kg(), "fermentableTable", "amount_kg", Units::kilograms))
           .arg(ferm->name());
    }
    str += ".";
@@ -459,13 +464,13 @@ PreInstruction Recipe::addExtracts(double timeRemaining)
    size = flist.size();
    for( i = 0; static_cast<int>(i) < size; ++i )
    {
-     Fermentable* ferm = flist[i];
-     if ( ferm->isExtract() )
-     {
-	str += QString("%1 %2, ")
-	    .arg(Brewtarget::displayAmount(ferm->amount_kg(), Units::kilograms))
-	    .arg(ferm->name());
-     }
+      Fermentable* ferm = flist[i];
+      if ( ferm->isExtract() )
+      {
+         str += QString("%1 %2, ")
+            .arg(Brewtarget::displayAmount(ferm->amount_kg(), "fermentableTable", "amount_kg", Units::kilograms))
+            .arg(ferm->name());
+      }
    }
    str += ".";
 
@@ -491,7 +496,7 @@ Instruction* Recipe::postboilFermentablesIns()
 
       hasFerms = true;
       tmp = QString("%1 %2, ")
-             .arg(Brewtarget::displayAmount(ferm->amount_kg(), Units::kilograms))
+             .arg(Brewtarget::displayAmount(ferm->amount_kg(), "fermentableTable", "amount_kg", Units::kilograms))
              .arg(ferm->name());
       str += tmp;
    }
@@ -527,16 +532,16 @@ Instruction* Recipe::postboilIns()
 
       wort_l = e->wortEndOfBoil_l(wortInBoil_l);
       str = tr("You should have %1 wort post-boil.")
-            .arg(Brewtarget::displayAmount( wort_l, Units::liters));
+            .arg(Brewtarget::displayAmount( wort_l, "tab_recipe", "batchSize_l", Units::liters));
       str += tr("\nYou anticipate losing %1 to trub and chiller loss.")
-            .arg(Brewtarget::displayAmount( e->trubChillerLoss_l(), Units::liters));
+            .arg(Brewtarget::displayAmount( e->trubChillerLoss_l(),"tab_recipe", "batchSize_l",  Units::liters));
       wort_l -= e->trubChillerLoss_l();
       if( e->topUpWater_l() > 0.0 )
           str += tr("\nAdd %1 top up water into primary.")
-               .arg(Brewtarget::displayAmount( e->topUpWater_l(), Units::liters));
+               .arg(Brewtarget::displayAmount( e->topUpWater_l(),"tab_recipe", "batchSize_l",  Units::liters));
       wort_l += e->topUpWater_l();
       str += tr("\nThe final volume in the primary is %1.")
-             .arg(Brewtarget::displayAmount(wort_l, Units::liters));
+             .arg(Brewtarget::displayAmount(wort_l,"tab_recipe", "batchSize_l",  Units::liters));
 
       ins = Database::instance().newInstruction(this);
       ins->setName(tr("Post boil"));
@@ -620,12 +625,13 @@ void Recipe::generateInstructions()
       timeRemaining = equipment()->boilTime_min();
    else
    {
-      timeRemaining = Brewtarget::timeQStringToSI(QInputDialog::getText(0,
+      timeRemaining = Brewtarget::qStringToSI(QInputDialog::getText(0,
                                         tr("Boil time"),
-                                        tr("You did not configure an equipment (which you really should), so tell me the boil time.")));
+                                        tr("You did not configure an equipment (which you really should), so tell me the boil time.")),
+                                        Units::minutes);
    }
    
-   str = tr("Bring the wort to a boil and hold for %1.").arg(Brewtarget::displayAmount( timeRemaining, Units::minutes));
+   str = tr("Bring the wort to a boil and hold for %1.").arg(Brewtarget::displayAmount( timeRemaining, "tab_recipe", "boilTime_min", Units::minutes));
    ins = Database::instance().newInstruction(this);
    ins->setName(tr("Start boil"));
    ins->setInterval(timeRemaining);
@@ -688,7 +694,7 @@ void Recipe::generateInstructions()
    addPreinstructions(miscSteps(Misc::Primary));
 
    str = tr("Let ferment until FG is %1.")
-         .arg(Brewtarget::displayAmount(fg()));
+         .arg(Brewtarget::displayAmount(fg(), "tab_recipe", "fg", Units::sp_grav, 3));
    ins = Database::instance().newInstruction(this);
    ins->setName(tr("Ferment"));
    ins->setDirections(str);
@@ -730,9 +736,9 @@ QString Recipe::nextAddToBoil(double& time)
       if( h->time_min() < time && h->time_min() > max )
       {
          ret = tr("Add %1 %2 to boil at %3.")
-               .arg(Brewtarget::displayAmount(h->amount_kg(), Units::kilograms))
+               .arg(Brewtarget::displayAmount(h->amount_kg(), "hopTable", "amount_kg", Units::kilograms))
                .arg(h->name())
-               .arg(Brewtarget::displayAmount(h->time_min(), Units::minutes));
+               .arg(Brewtarget::displayAmount(h->time_min(),"hopTable", "time",  Units::minutes));
 
          max = h->time_min();
          foundSomething = true;
@@ -750,12 +756,12 @@ QString Recipe::nextAddToBoil(double& time)
       {
          ret = tr("Add %1 %2 to boil at %3.");
          if( m->amountIsWeight() )
-            ret = ret.arg(Brewtarget::displayAmount(m->amount(), Units::kilograms));
+            ret = ret.arg(Brewtarget::displayAmount(m->amount(), "miscTableModel", "amount", Units::kilograms));
          else
-            ret = ret.arg(Brewtarget::displayAmount(m->amount(), Units::liters));
+            ret = ret.arg(Brewtarget::displayAmount(m->amount(), "miscTableModel", "amount",  Units::liters));
 
          ret = ret.arg(m->name());
-         ret = ret.arg(Brewtarget::displayAmount(m->time(), Units::minutes));
+         ret = ret.arg(Brewtarget::displayAmount(m->time(), "miscTableModel", "time", Units::minutes));
          max = m->time();
          foundSomething = true;
       }
@@ -1183,13 +1189,20 @@ double Recipe::boilGrav()
    return _boilGrav;
 }
 
-double Recipe::calories()
+double Recipe::calories12oz()
 {
    if( _uninitializedCalcs )
       recalcAll();
    return _calories;
 }
 
+double Recipe::calories33cl()
+{
+   if( _uninitializedCalcs )
+      recalcAll();
+   return _calories*3.3/3.55;
+}
+
 double Recipe::wortFromMash_l()
 {
    if( _uninitializedCalcs )
@@ -1299,141 +1312,36 @@ QList<Water*> Recipe::waters() const
 }
 
 //==============================Getters===================================
-QString Recipe::name() const
-{
-   return get("name").toString();
-}
+QString Recipe::name()             const { return get("name").toString(); }
+QString Recipe::type()             const { return get("type").toString(); }
+QString Recipe::brewer()           const { return get("brewer").toString(); }
+QString Recipe::asstBrewer()       const { return get("assistant_brewer").toString(); }
+QString Recipe::notes()            const { return get("notes").toString(); }
+QString Recipe::tasteNotes()       const { return get("taste_notes").toString(); }
+QString Recipe::primingSugarName() const { return get("priming_sugar_name").toString(); }
 
-QString Recipe::type() const
-{
-   return get("type").toString();
-}
+bool Recipe::forcedCarbonation()   const { return get("forced_carb").toBool(); }
 
-QString Recipe::brewer() const
-{
-   return get("brewer").toString();
-}
-
-double Recipe::batchSize_l() const
-{
-   return get("batch_size").toDouble();
-}
-
-double Recipe::boilSize_l() const
-{
-   return get("boil_size").toDouble();
-}
-
-double Recipe::boilTime_min() const
-{
-   return get("boil_time").toDouble();
-}
-
-double Recipe::efficiency_pct() const
-{
-   return get("efficiency").toDouble();
-}
-
-QString Recipe::asstBrewer() const
-{
-   return get("assistant_brewer").toString();
-}
-
-QString Recipe::notes() const
-{
-   return get("notes").toString();
-}
-
-QString Recipe::tasteNotes() const
-{
-   return get("taste_notes").toString();
-}
-
-double Recipe::tasteRating() const
-{
-   return get("taste_rating").toDouble();
-}
-
-int Recipe::fermentationStages() const
-{
-   return get("fermentation_stages").toInt();
-}
-
-double Recipe::primaryAge_days() const
-{
-   return get("primary_age").toDouble();
-}
-
-double Recipe::primaryTemp_c() const
-{
-   return get("primary_temp").toDouble();
-}
-
-double Recipe::secondaryAge_days() const
-{
-   return get("secondary_age").toDouble();
-}
-
-double Recipe::secondaryTemp_c() const
-{
-   return get("secondary_temp").toDouble();
-}
-
-double Recipe::tertiaryAge_days() const
-{
-   return get("tertiary_age").toDouble();
-}
-
-double Recipe::tertiaryTemp_c() const
-{
-   return get("tertiary_temp").toDouble();
-}
-
-double Recipe::age_days() const
-{
-   return get("age").toDouble();
-}
-
-double Recipe::ageTemp_c() const
-{
-   return get("age_temp").toDouble();
-}
-
-QDate Recipe::date() const
-{
-   return QDate::fromString( get("date").toString(), "d/M/yyyy");
-}
-
-double Recipe::carbonation_vols() const
-{
-   return get("carb_volume").toDouble();
-}
-
-bool Recipe::forcedCarbonation() const
-{
-   return get("forced_carb").toBool();
-}
-
-QString Recipe::primingSugarName() const
-{
-   return get("priming_sugar_name").toString();
-}
-
-double Recipe::carbonationTemp_c() const
-{
-   return get("carbonationTemp_c").toDouble();
-}
-
-double Recipe::primingSugarEquiv() const
-{
-   return get("priming_sugar_equiv").toDouble();
-}
-
-double Recipe::kegPrimingFactor() const
-{
-   return get("keg_priming_factor").toDouble();
-}
+double Recipe::batchSize_l()       const { return get("batch_size").toDouble(); }
+double Recipe::boilSize_l()        const { return get("boil_size").toDouble(); }
+double Recipe::boilTime_min()      const { return get("boil_time").toDouble(); }
+double Recipe::efficiency_pct()    const { return get("efficiency").toDouble(); }
+double Recipe::tasteRating()       const { return get("taste_rating").toDouble(); }
+double Recipe::primaryAge_days()   const { return get("primary_age").toDouble(); }
+double Recipe::primaryTemp_c()     const { return get("primary_temp").toDouble(); }
+double Recipe::secondaryAge_days() const { return get("secondary_age").toDouble(); }
+double Recipe::secondaryTemp_c()   const { return get("secondary_temp").toDouble(); }
+double Recipe::tertiaryAge_days()  const { return get("tertiary_age").toDouble(); }
+double Recipe::tertiaryTemp_c()    const { return get("tertiary_temp").toDouble(); }
+double Recipe::age_days()          const { return get("age").toDouble(); }
+double Recipe::ageTemp_c()         const { return get("age_temp").toDouble(); }
+double Recipe::carbonation_vols()  const { return get("carb_volume").toDouble(); }
+double Recipe::carbonationTemp_c() const { return get("carbonationTemp_c").toDouble(); }
+double Recipe::primingSugarEquiv() const { return get("priming_sugar_equiv").toDouble(); }
+double Recipe::kegPrimingFactor()  const { return get("keg_priming_factor").toDouble(); }
 
+int Recipe::fermentationStages()   const { return get("fermentation_stages").toInt(); }
+QDate Recipe::date()               const { return QDate::fromString( get("date").toString(), "d/M/yyyy"); }
 //=============================Removers========================================
 
 // Returns true if var is found and removed.
@@ -1511,10 +1419,9 @@ void Recipe::recalcABV_pct()
 {
    double ret;
 
-   // George Fix: Brewing Science and Practice, page 686.
-   // The multiplicative factor actually varies from
-   // 125 for weak beers to 135 for strong beers.
-   ret = 130*(_og_fermentable - _fg_fermentable);
+   // The complex formula, and variations comes from Ritchie Products Ltd, (Zymurgy, Summer 1995, vol. 18, no. 2)
+   // Michael L. Hall’s article Brew by the Numbers: Add Up What’s in Your Beer, and Designing Great Beers by Daniels.
+   ret = (76.08 * (_og_fermentable - _fg_fermentable) / (1.775 - _og_fermentable)) * (_fg_fermentable / 0.794);
   
    if ( ret != _ABV_pct ) 
    {
@@ -1721,26 +1628,7 @@ void Recipe::recalcGrains_kg()
 
 void Recipe::recalcSRMColor()
 {
-   QColor tmp;
-   /*
-   //==========My approximation from a photo and spreadsheet===========
-   double red = 232.9 * pow( (double)0.93, _color_srm );
-   double green = (double)-106.25 * log(_color_srm) + 280.9;
-
-   int r = (int)Algorithms::Instance().round(red);
-   int g = (int)Algorithms::Instance().round(green);
-   int b = 0;
-   */
-   
-   // Philip Lee's approximation from a color swatch and curve fitting.
-   int r = 0.5 + (272.098 - 5.80255*_color_srm); if( r > 253.0 ) r = 253.0;
-   int g = 0.5 + (2.41975e2 - 1.3314e1*_color_srm + 1.881895e-1*_color_srm*_color_srm);
-   int b = 0.5 + (179.3 - 28.7*_color_srm);
-   
-   r = (r < 0) ? 0 : ((r > 255)? 255 : r);
-   g = (g < 0) ? 0 : ((g > 255)? 255 : g);
-   b = (b < 0) ? 0 : ((b > 255)? 255 : b);
-   tmp.setRgb( r, g, b );
+   QColor tmp = Algorithms::srmToColor(_color_srm);
 
    if ( tmp != _SRMColor )
    {
@@ -1767,6 +1655,9 @@ void Recipe::recalcCalories()
    // Alcohol by weight?
    abw = (startPlato-RE)/(2.0665 - (0.010665 * startPlato));
 
+   // The final results of this formular are calories per 100 ml. 
+   // The 3.55 puts it in terms of 12 oz. I really should have stored it
+   // without that adjust.
    tmp = ((6.9*abw) + 4.0 * (RE-0.1)) * ffg * 3.55;
 
    //! If there are no fermentables in the recipe, if there is no mash, etc.,
@@ -1785,12 +1676,14 @@ void Recipe::recalcCalories()
 // other efficiency calculations need access to the maximum theoretical sugars
 // available. The only way I can see of doing that which doesn't suck is to
 // split that calcuation out of recalcOgFg();
-QHash<QString,double> Recipe::calcTotalPoints(bool preBoil)
+QHash<QString,double> Recipe::calcTotalPoints()
 {
    int i;
    double sugar_kg_ignoreEfficiency = 0.0;
    double sugar_kg                  = 0.0;
    double nonFermetableSugars_kg    = 0.0;
+   double lateAddition_kg           = 0.0;
+   double lateAddition_kg_ignoreEff = 0.0;
 
    Fermentable* ferm;
 
@@ -1801,24 +1694,31 @@ QHash<QString,double> Recipe::calcTotalPoints(bool preBoil)
    {
       ferm = ferms[i];
 
-      // skip any non-mashed fermentable if this is for the preboil
-      // calculations
-      if ( preBoil && ! ferm->isMashed() )
-         continue;
       // If we have some sort of non-grain, we have to ignore efficiency.
       if( ferm->isSugar() || ferm->isExtract() )
       {
          sugar_kg_ignoreEfficiency += ferm->equivSucrose_kg();
+
+         if (ferm->addAfterBoil())
+            lateAddition_kg_ignoreEff += ferm->equivSucrose_kg();
+
          if ( !isFermentableSugar(ferm) )
            nonFermetableSugars_kg += ferm->equivSucrose_kg();
       }
       else
+      {
          sugar_kg += ferm->equivSucrose_kg();
+
+         if (ferm->addAfterBoil())
+            lateAddition_kg += ferm->equivSucrose_kg();
+      }
    }   
    
    ret.insert("sugar_kg", sugar_kg);
    ret.insert("nonFermetableSugars_kg", nonFermetableSugars_kg);
    ret.insert("sugar_kg_ignoreEfficiency", sugar_kg_ignoreEfficiency);
+   ret.insert("lateAddition_kg", lateAddition_kg);
+   ret.insert("lateAddition_kg_ignoreEff", lateAddition_kg_ignoreEff);
 
    return ret;
 
@@ -1828,20 +1728,22 @@ void Recipe::recalcBoilGrav()
 {
    double sugar_kg = 0.0;
    double sugar_kg_ignoreEfficiency = 0.0;
+   double lateAddition_kg           = 0.0;
+   double lateAddition_kg_ignoreEff = 0.0;
    double ret;
    QHash<QString,double> sugars;
 
-   sugars = calcTotalPoints(true);
+   sugars = calcTotalPoints();
    sugar_kg = sugars.value("sugar_kg");
    sugar_kg_ignoreEfficiency = sugars.value("sugar_kg_ignoreEfficiency");
+   lateAddition_kg = sugars.value("lateAddition_kg");
+   lateAddition_kg_ignoreEff = sugars.value("lateAddition_kg_ignoreEff");
    
    // Since the efficiency refers to how much sugar we get into the fermenter,
    // we need to adjust for that here.
-   sugar_kg = (efficiency_pct()/100.0 * sugar_kg + sugar_kg_ignoreEfficiency);
-   if( equipment() )
-      sugar_kg = sugar_kg / (1 - equipment()->trubChillerLoss_l()/_finalVolumeNoLosses_l);
+   sugar_kg = (efficiency_pct()/100.0 * (sugar_kg - lateAddition_kg) + sugar_kg_ignoreEfficiency - lateAddition_kg_ignoreEff);
 
-   ret = Algorithms::Instance().PlatoToSG_20C20C( Algorithms::Instance().getPlato(sugar_kg, boilSize_l()) );
+   ret = Algorithms::PlatoToSG_20C20C( Algorithms::getPlato(sugar_kg, boilSize_l()) );
  
    if ( ret != _boilGrav )
    {
@@ -1874,12 +1776,12 @@ void Recipe::recalcOgFg()
    // if if we aren't initialized yet.
    if ( _uninitializedCalcs )
    {
-      _og = get("og").toDouble();
-      _fg = get("fg").toDouble();
+      _og = Brewtarget::toDouble(this,"og","Recipe::recalcOgFg()");
+      _fg = Brewtarget::toDouble(this,"fg","Recipe::recalcOgFg()");
    }
 
    // Find out how much sugar we have.
-   sugars = calcTotalPoints(false);
+   sugars = calcTotalPoints();
    sugar_kg                  = sugars.value("sugar_kg");
    sugar_kg_ignoreEfficiency = sugars.value("sugar_kg_ignoreEfficiency");
    nonFermetableSugars_kg    = sugars.value("nonFermetableSugars_kg");
@@ -1895,7 +1797,7 @@ void Recipe::recalcOgFg()
          ratio = 1.0;
       else if( ratio < 0.0 )
          ratio = 0.0;
-      else if( Algorithms::Instance().isnan(ratio) )
+      else if( Algorithms::isNan(ratio) )
          ratio = 1.0;
       // Ignore this again since it should be included in efficiency.
       //sugar_kg *= ratio;
@@ -1905,17 +1807,17 @@ void Recipe::recalcOgFg()
    }
 
    sugar_kg = sugar_kg * efficiency_pct()/100.0 + sugar_kg_ignoreEfficiency;
-   plato = Algorithms::Instance().getPlato( sugar_kg, _finalVolumeNoLosses_l);
+   plato = Algorithms::getPlato( sugar_kg, _finalVolumeNoLosses_l);
 
-   tmp_og = Algorithms::Instance().PlatoToSG_20C20C( plato );
+   tmp_og = Algorithms::PlatoToSG_20C20C( plato );
    tmp_pnts = (tmp_og-1)*1000.0;
    if ( nonFermetableSugars_kg != 0.0 )
    {
       ferm_kg = sugar_kg - nonFermetableSugars_kg;
-      plato = Algorithms::Instance().getPlato( ferm_kg, _finalVolumeNoLosses_l);
-      _og_fermentable = Algorithms::Instance().PlatoToSG_20C20C( plato );
-      plato = Algorithms::Instance().getPlato( nonFermetableSugars_kg, _finalVolumeNoLosses_l); 
-      tmp_ferm_pnts = ((Algorithms::Instance().PlatoToSG_20C20C( plato ))-1)*1000.0;
+      plato = Algorithms::getPlato( ferm_kg, _finalVolumeNoLosses_l);
+      _og_fermentable = Algorithms::PlatoToSG_20C20C( plato );
+      plato = Algorithms::getPlato( nonFermetableSugars_kg, _finalVolumeNoLosses_l); 
+      tmp_ferm_pnts = ((Algorithms::PlatoToSG_20C20C( plato ))-1)*1000.0;
    }
    else
    {
@@ -1977,8 +1879,8 @@ double Recipe::ibuFromHop(Hop const* hop)
 {
    Equipment* equip = equipment();
    double ibus = 0.0;
-   double fwhAdjust = Brewtarget::option("firstWortHopAdjustment", 1.1).toDouble();
-   double mashHopAdjust = Brewtarget::option("mashHopAdjustment", 0).toDouble();
+   double fwhAdjust = Brewtarget::toDouble(Brewtarget::option("firstWortHopAdjustment", 1.1).toString(), "Recipe::ibmFromHop()");
+   double mashHopAdjust = Brewtarget::toDouble(Brewtarget::option("mashHopAdjustment", 0).toString(), "Recipe::ibmFromHop()");
    
    if( hop == 0 )
       return 0.0;
@@ -1986,34 +1888,47 @@ double Recipe::ibuFromHop(Hop const* hop)
    double AArating = hop->alpha_pct()/100.0;
    double grams = hop->amount_kg()*1000.0;
    double minutes = hop->time_min();
-   double boilGrav_final = _boilGrav; 
    // Assume 100% utilization until further notice
    double hopUtilization = 1.0;
    // Assume 60 min boil until further notice
    int boilTime = 60;
-   double avgBoilGrav;
+
+   // NOTE: we used to carefully calculate the average boil gravity and use it in the
+   // IBU calculations. However, due to John Palmer
+   // (http://homebrew.stackexchange.com/questions/7343/does-wort-gravity-affect-hop-utilization),
+   // it seems more appropriate to just use the OG directly, since it is the total
+   // amount of break material that truly affects the IBUs.
    
    if( equip )
    {
-      boilGrav_final = _boilVolume_l / equip->wortEndOfBoil_l( _boilVolume_l ) * (_boilGrav-1) + 1;
       hopUtilization = equip->hopUtilization_pct() / 100.0;
       boilTime = equip->boilTime_min();
    }
    
-   avgBoilGrav = (_boilGrav + boilGrav_final) / 2;
-   
    if( hop->use() == Hop::Boil)
-      ibus = IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, avgBoilGrav, minutes );
+      ibus = IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, _og, minutes );
    else if( hop->use() == Hop::First_Wort )
-      ibus = fwhAdjust * IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, avgBoilGrav, boilTime );
+      ibus = fwhAdjust * IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, _og, boilTime );
    else if( hop->use() == Hop::Mash && mashHopAdjust > 0.0 )
-      ibus = mashHopAdjust * IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, avgBoilGrav, boilTime );
+      ibus = mashHopAdjust * IbuMethods::getIbus( AArating, grams, _finalVolumeNoLosses_l, _og, boilTime );
 
-   // Adjust for hop form.
-   if( hop->form() == Hop::Leaf )
-      ibus *= 0.90;
-   else if( hop->form() == Hop::Plug )
-      ibus *= 0.92;
+   // Adjust for hop form. Tinseth's table was created from whole cone data,
+   // and it seems other formulae are optimized that way as well. So, the
+   // utilization is considered unadjusted for whole cones, and adjusted
+   // up for plugs and pellets.
+   //
+   // - http://www.realbeer.com/hops/FAQ.html
+   // - https://groups.google.com/forum/#!topic/brewtarget-help/mv2qvWBC4sU
+   switch( hop->form() ) {
+   case Hop::Plug:
+      hopUtilization *= 1.02;
+      break;
+   case Hop::Pellet:
+      hopUtilization *= 1.10;
+      break;
+   default:
+      break;
+   }
 
    // Adjust for hop utilization. 
    ibus *= hopUtilization;
@@ -2046,13 +1961,13 @@ QList<QString> Recipe::getReagents( QList<Fermentable*> ferms )
          if ( i+1 < ferms.size() )
          {
             tmp = QString("%1 %2, ")
-                  .arg(Brewtarget::displayAmount(ferms[i]->amount_kg(), Units::kilograms))
+                  .arg(Brewtarget::displayAmount(ferms[i]->amount_kg(), "fermentableTable", "amount_kg", Units::kilograms))
                   .arg(ferms[i]->name());
          }
          else
          {
             tmp = QString("%1 %2 ")
-                  .arg(Brewtarget::displayAmount(ferms[i]->amount_kg(), Units::kilograms))
+                  .arg(Brewtarget::displayAmount(ferms[i]->amount_kg(),"fermentableTable", "amount_kg",  Units::kilograms))
                   .arg(ferms[i]->name());
          }
          reagents.append(tmp);
@@ -2072,7 +1987,7 @@ QList<QString> Recipe::getReagents(QList<Hop*> hops, bool firstWort)
          (hops[i]->use() == Hop::First_Wort) )
       {
          tmp = QString("%1 %2,")
-               .arg(Brewtarget::displayAmount(hops[i]->amount_kg(), Units::kilograms))
+               .arg(Brewtarget::displayAmount(hops[i]->amount_kg(), "hopTable", "amount_kg",  Units::kilograms))
                .arg(hops[i]->name());
          reagents.append(tmp);
       }
@@ -2093,14 +2008,14 @@ QList<QString> Recipe::getReagents( QList<MashStep*> msteps )
       if ( i+1 < msteps.size() ) 
       {
          tmp = tr("%1 water to %2, ")
-                .arg(Brewtarget::displayAmount(msteps[i]->infuseAmount_l(), Units::liters))
-                .arg(Brewtarget::displayAmount(msteps[i]->infuseTemp_c(), Units::celsius));
+                .arg(Brewtarget::displayAmount(msteps[i]->infuseAmount_l(), "mashStepTableModel", "infuseAmount_l", Units::liters))
+                .arg(Brewtarget::displayAmount(msteps[i]->infuseTemp_c(),"mashStepTableModel", "infuseTemp_c",  Units::celsius));
       }
       else 
       {
          tmp = tr("%1 water to %2 ")
-                .arg(Brewtarget::displayAmount(msteps[i]->infuseAmount_l(), Units::liters))
-                .arg(Brewtarget::displayAmount(msteps[i]->infuseTemp_c(), Units::celsius));
+                .arg(Brewtarget::displayAmount(msteps[i]->infuseAmount_l(), "mashStepTableModel", "infuseAmount_l", Units::liters))
+                .arg(Brewtarget::displayAmount(msteps[i]->infuseTemp_c(), "mashStepTableModel", "infuseTemp_c", Units::celsius));
       }
       reagents.append(tmp);
    }
@@ -2134,6 +2049,18 @@ void Recipe::acceptHopChange(Hop* hop)
    recalcIBU();
 }
 
+void Recipe::acceptYeastChange(QMetaProperty prop, QVariant val)
+{
+   recalcOgFg();
+   recalcABV_pct();
+}
+
+void Recipe::acceptYeastChange(Yeast* yeast)
+{
+   recalcOgFg();
+   recalcABV_pct();
+}
+
 void Recipe::acceptMashChange(QMetaProperty prop, QVariant val)
 {
    Mash* mashSend = qobject_cast<Mash*>(sender());
