@@ -1,17 +1,21 @@
 /*
- * recipe.h is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * recipe.h is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Jeff Bailey <skydvr38@verizon.net>
+ * - Kregg K <gigatropolis@yahoo.com>
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -45,6 +49,7 @@ class Water;
 class Instruction;
 class PreInstruction;
 class BrewNote;
+class MashStep;
 
 //! \brief Compares recipes based on name.
 bool operator<(Recipe &r1, Recipe &r2 );
@@ -128,7 +133,7 @@ public:
    Q_PROPERTY( double primingSugarEquiv READ primingSugarEquiv WRITE setPrimingSugarEquiv /*NOTIFY changed*/ /*changedPrimingSugarEquiv*/ )
    //! \brief The factor required to convert the amount of sugar required for bottles to keg (usually about 0.5).
    Q_PROPERTY( double kegPrimingFactor READ kegPrimingFactor WRITE setKegPrimingFactor /*NOTIFY changed*/ /*changedKegPrimingFactor*/ )
-   
+  
    // Calculated stored properties.
    //! \brief The calculated OG.
    Q_PROPERTY( double og READ og WRITE setOg /*NOTIFY changed*/ /*changedOg*/ )
@@ -159,7 +164,7 @@ public:
    //! \brief The calculated final volume into the primary in liters.
    Q_PROPERTY( double finalVolume_l READ finalVolume_l /*WRITE*/ /*NOTIFY changed*/ /*changedEstimateFinalVolume_l*/ STORED false)
    //! \brief The calculated Calories per 12 oz. (kcal).
-   Q_PROPERTY( double calories READ calories /*WRITE*/ /*NOTIFY changed*/ /*changedEstimateCalories*/ STORED false)
+   Q_PROPERTY( double calories READ calories12oz /*WRITE*/ /*NOTIFY changed*/ /*changedEstimateCalories*/ STORED false)
    //! \brief The amount of grains in the mash in kg.
    Q_PROPERTY( double grainsInMash_kg READ grainsInMash_kg /*WRITE*/ /*NOTIFY changed*/ /*changedGrainsInMash_kg*/ STORED false)
    //! \brief The total amount of grains in the recipe in kg.
@@ -208,9 +213,7 @@ public:
    //void addInstruction( Instruction* ins );
    void removeInstruction( Instruction* ins );
    /*!
-    * \brief Swap instructions j and k.
-    * \param j some integer less than getNumInstructions()
-    * \param k some integer less than getNumInstructions()
+    * \brief Swap instructions \c ins1 and \c ins2
     */
    void swapInstructions( Instruction* ins1, Instruction* ins2 );
    //! \brief Remove all instructions.
@@ -269,7 +272,8 @@ public:
    double boilVolume_l();
    double postBoilVolume_l();
    double finalVolume_l();
-   double calories();
+   double calories12oz();
+   double calories33cl();
    double grainsInMash_kg();
    double grains_kg();
    QList<double> IBUs();
@@ -304,7 +308,7 @@ public:
    QList<QString> getReagents( QList<Fermentable*> ferms );
    QList<QString> getReagents( QList<MashStep*> msteps );
    QList<QString> getReagents( QList<Hop*> hops, bool firstWort = false );
-   QHash<QString,double> calcTotalPoints(bool preBoil = false);
+   QHash<QString,double> calcTotalPoints();
    
 signals:
    //! \brief Emitted when \c name() changes.
@@ -314,10 +318,12 @@ public slots:
    void acceptEquipChange(QMetaProperty prop, QVariant val);
    void acceptFermChange(QMetaProperty prop, QVariant val);
    void acceptHopChange(QMetaProperty prop, QVariant val);
+   void acceptYeastChange(QMetaProperty prop, QVariant val);
    void acceptMashChange(QMetaProperty prop, QVariant val);
 
    void acceptFermChange(Fermentable* ferm);
    void acceptHopChange(Hop* hop);
+   void acceptYeastChange(Yeast* yeast);
    void acceptMashChange(Mash* mash);
 
    // Setters
