@@ -1,17 +1,19 @@
 /*
- * style.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * style.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -239,123 +241,31 @@ void Style::setExamples( const QString& var )
 }
 
 //============================="GET" METHODS====================================
-QString Style::name() const
-{
-   return get("name").toString();
-}
+QString Style::name() const { return get("name").toString(); }
+QString Style::category() const { return get("category").toString(); }
+QString Style::categoryNumber() const { return get("category_number").toString(); }
+QString Style::styleLetter() const { return get("style_letter").toString(); }
+QString Style::styleGuide() const { return get("style_guide").toString(); }
+QString Style::notes() const { return get("notes").toString(); }
+QString Style::profile() const { return get("profile").toString(); }
+QString Style::ingredients() const { return get("ingredients").toString(); }
+QString Style::examples() const { return get("examples").toString(); }
 
-QString Style::category() const
-{
-   return get("category").toString();
-}
+const Style::Type Style::type() const { return static_cast<Style::Type>(types.indexOf(get("s_type").toString())); }
+const QString Style::typeString() const { return types.at(type()); }
 
-QString Style::categoryNumber() const
-{
-   return get("category_number").toString();
-}
+double Style::ogMin()        const { return get("og_min").toDouble(); }
+double Style::ogMax()        const { return get("og_max").toDouble(); }
+double Style::fgMin()        const { return get("fg_min").toDouble(); }
+double Style::fgMax()        const { return get("fg_max").toDouble(); }
+double Style::ibuMin()       const { return get("ibu_min").toDouble(); }
+double Style::ibuMax()       const { return get("ibu_max").toDouble(); }
+double Style::colorMin_srm() const { return get("color_min").toDouble(); }
+double Style::colorMax_srm() const { return get("color_max").toDouble(); }
+double Style::carbMin_vol()  const { return get("carb_min").toDouble(); }
+double Style::carbMax_vol()  const { return get("carb_max").toDouble(); }
+double Style::abvMin_pct()   const { return get("abv_min").toDouble(); }
+double Style::abvMax_pct()   const { return get("abv_max").toDouble(); }
 
-QString Style::styleLetter() const
-{
-   return get("style_letter").toString();
-}
-
-QString Style::styleGuide() const
-{
-   return get("style_guide").toString();
-}
-
-const Style::Type Style::type() const
-{
-   return static_cast<Style::Type>(types.indexOf(get("s_type").toString()));
-}
-
-const QString Style::typeString() const
-{
-   return types.at(type());
-}
-
-double Style::ogMin() const
-{
-   return get("og_min").toDouble();
-}
-
-double Style::ogMax() const
-{
-   return get("og_max").toDouble();
-}
-
-double Style::fgMin() const
-{
-   return get("fg_min").toDouble();
-}
-
-double Style::fgMax() const
-{
-   return get("fg_max").toDouble();
-}
-
-double Style::ibuMin() const
-{
-   return get("ibu_min").toDouble();
-}
-
-double Style::ibuMax() const
-{
-   return get("ibu_max").toDouble();
-}
-
-double Style::colorMin_srm() const
-{
-   return get("color_min").toDouble();
-}
-
-double Style::colorMax_srm() const
-{
-   return get("color_max").toDouble();
-}
-
-double Style::carbMin_vol() const
-{
-   return get("carb_min").toDouble();
-}
-
-double Style::carbMax_vol() const
-{
-   return get("carb_max").toDouble();
-}
-
-double Style::abvMin_pct() const
-{
-   return get("abv_min").toDouble();
-}
-
-double Style::abvMax_pct() const
-{
-   return get("abv_max").toDouble();
-}
-
-QString Style::notes() const
-{
-   return get("notes").toString();
-}
-
-QString Style::profile() const
-{
-   return get("profile").toString();
-}
-
-QString Style::ingredients() const
-{
-   return get("ingredients").toString();
-}
-
-QString Style::examples() const
-{
-   return get("examples").toString();
-}
-
-bool Style::isValidType( const QString &str )
-{
-   return types.contains( str );
-}
+bool Style::isValidType( const QString &str ) { return types.contains( str ); }
 
