@@ -1,17 +1,20 @@
 /*
- * unit.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * unit.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Mik Firestone <mikfire@gmail.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - Rob Taylor <robtaylor@floopily.org>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -19,9 +22,11 @@
 #include <QStringList>
 #include <string>
 #include <iostream>
+#include <QRegExp>
 #include <QDebug>
 #include "unit.h"
 #include "brewtarget.h"
+#include "Algorithms.h"
 
 QMultiMap<QString, Unit*> Unit::nameToUnit;
 bool Unit::isMapSetup = false;
@@ -30,21 +35,24 @@ bool Unit::isMapSetup = false;
 KilogramUnit* Units::kilograms = new KilogramUnit();
 GramUnit* Units::grams = new GramUnit();
 MilligramUnit* Units::milligrams = new MilligramUnit();
+
 PoundUnit* Units::pounds = new PoundUnit();
 OunceUnit* Units::ounces = new OunceUnit();
 // === Volume ===
 LiterUnit* Units::liters = new LiterUnit();
 MilliliterUnit* Units::milliliters = new MilliliterUnit();
+
 USBarrelUnit* Units::us_barrels = new USBarrelUnit();
 USGallonUnit* Units::us_gallons = new USGallonUnit();
 USQuartUnit* Units::us_quarts = new USQuartUnit();
 USCupUnit* Units::us_cups = new USCupUnit();
+USTablespoonUnit* Units::us_tablespoons = new USTablespoonUnit();
+USTeaspoonUnit* Units::us_teaspoons = new USTeaspoonUnit();
+
 ImperialBarrelUnit* Units::imperial_barrels = new ImperialBarrelUnit();
 ImperialGallonUnit* Units::imperial_gallons = new ImperialGallonUnit();
 ImperialQuartUnit* Units::imperial_quarts = new ImperialQuartUnit();
 ImperialCupUnit* Units::imperial_cups = new ImperialCupUnit();
-USTablespoonUnit* Units::us_tablespoons = new USTablespoonUnit();
-USTeaspoonUnit* Units::us_teaspoons = new USTeaspoonUnit();
 ImperialTablespoonUnit* Units::imperial_tablespoons = new ImperialTablespoonUnit();
 ImperialTeaspoonUnit* Units::imperial_teaspoons = new ImperialTeaspoonUnit();
 // === Time ===
@@ -59,143 +67,129 @@ KelvinUnit* Units::kelvin = new KelvinUnit();
 // === Color ===
 SRMUnit* Units::srm = new SRMUnit();
 EBCUnit* Units::ebc = new EBCUnit();
+// == density ===
+SgUnit* Units::sp_grav = new SgUnit();
+PlatoUnit* Units::plato = new PlatoUnit();
 
-// Return the equivalent of 'amount' 'fromUnit's in 'toUnit's.
-double Unit::convert( double amount, QString& fromUnit, QString& toUnit )
+QString Unit::unitFromString(QString qstr)
 {
-   double SI;
+   QRegExp amtUnit;
 
-   if( ! Unit::isMapSetup )
-      Unit::setupMap();
+   // Make sure we get the right decimal point (. or ,) and the right grouping
+   // separator (, or .). Some locales write 1.000,10 and other write
+   // 1,000.10. We need to catch both
+   QString decimal = QRegExp::escape( QLocale::system().decimalPoint());
+   QString grouping = QRegExp::escape(QLocale::system().groupSeparator());
 
-   // TODO: warn somebody if the units aren't in the map.
-   Unit* f;
-   Unit* t;
+   amtUnit.setPattern("((?:\\d+" + grouping + ")?\\d+(?:" + decimal + "\\d+)?|" + decimal + "\\d+)\\s*(\\w+)?");
+   amtUnit.setCaseSensitivity(Qt::CaseInsensitive);
 
-   f = getUnit(fromUnit);
-   t = getUnit(toUnit, false);
+   // if the regex dies, return 0.0
+   if (amtUnit.indexIn(qstr) == -1)
+      return QString("?");
 
-   // Freak out if we can't find the units or if they're not the same type.
-   if( f == 0 || t == 0  || f->getUnitType() != t->getUnitType() )
-      return 0.0;
+   // Get the unit from the second capture
+   return amtUnit.cap(2);
 
-   SI = f->toSI(amount);
-   return t->fromSI(SI);
 }
 
-// Gets the unit with the appropriate name. Select the one consistent
-// with the current system (like Brewtarget::getWeightUnitSystem())
-// if possible. Otherwise, get a unit of type USCustomary or Any.
-Unit* Unit::getUnit(QString& name, bool matchCurrentSystem)
+double Unit::valueFromString(QString qstr)
 {
-   Unit* u;
-   QMap<QString, Unit*>::iterator i = nameToUnit.find(name);
+   QRegExp amtUnit;
 
-   // First, try to find a unit consistent with the measurement system.
-   for( ; i != nameToUnit.end() && i.key() == name; ++i )
-   {
-      u = i.value();
-      if( u == 0 )
-         continue;
+   // Make sure we get the right decimal point (. or ,) and the right grouping
+   // separator (, or .). Some locales write 1.000,10 and other write
+   // 1,000.10. We need to catch both
+   QString decimal = QRegExp::escape( QLocale::system().decimalPoint());
+   QString grouping = QRegExp::escape(QLocale::system().groupSeparator());
 
-      int type = u->getUnitType();
-      int system = u->getUnitOrTempSystem();
+   amtUnit.setPattern("((?:\\d+" + grouping + ")?\\d+(?:" + decimal + "\\d+)?|" + decimal + "\\d+)\\s*(\\w+)?");
+   amtUnit.setCaseSensitivity(Qt::CaseInsensitive);
 
-      if( type == Temp && system == Brewtarget::getTemperatureScale() )
-         return u;
-      else if( type == Mass )
-      {
-         if( system == Any || system == Brewtarget::getWeightUnitSystem() )
-            return u;
-
-         if( (Brewtarget::getWeightUnitSystem() == USCustomary || Brewtarget::getWeightUnitSystem() == Imperial)
-            && system == ImperialAndUS)
-            return u;
-      }
-      else if( type == Volume )
-      {
-         if( system == Any || system == Brewtarget::getVolumeUnitSystem() )
-            return u;
-
-         if( (Brewtarget::getVolumeUnitSystem() == USCustomary || Brewtarget::getVolumeUnitSystem() == Imperial)
-            && system == ImperialAndUS )
-            return u;
-      }
-      else if( type == Time )
-         return u;
-   }
-
-   i = nameToUnit.find(name);
-
-   // Now, just try to find a unit with the USCustomary or Any system.
-   for( ; i != nameToUnit.end() && i.key() == name; ++i )
-   {
-      u = i.value();
-      if( u == 0 )
-         continue;
-
-      int system = u->getUnitOrTempSystem();
-
-      if( system == Any || system == USCustomary || system == ImperialAndUS || matchCurrentSystem == false )
-         return u;
-   }
-
-   return 0;
-}
-
-// Translates something like "5.0 gal" into the appropriate SI units.
-double Unit::qstringToSI( QString qstr, Unit** unit, bool matchCurrentSystem )
-{
-   if( ! Unit::isMapSetup )
-      Unit::setupMap();
-
-   QStringList list1 = qstr.split(" ");
-
-   if( list1.size() < 1 ) // Didn't even provide a number.
+   // if the regex dies, return 0.0
+   if (amtUnit.indexIn(qstr) == -1)
       return 0.0;
-   else if( list1.size() < 2  ) // Only provided a number.
-   {
-      // If we don't have units, just assume we're dealing with mass.
-      switch(Brewtarget::weightUnitSystem)
-      {
-         case USCustomary:
-         case Imperial:
-            return Units::pounds->toSI(list1[0].toDouble());
 
-         case SI:
-         default:
-            return list1[0].toDouble();
-      }
-   }
-   else // Provided a number and unit.
-   {
-      Unit* u = getUnit(list1[1], matchCurrentSystem);
-      if( unit != 0 )
-         *unit = u;
-      
-      if( u == 0 ) // Invalid unit since it's not in the map.
-         return list1[0].toDouble(); // Assume units are already SI.
-      else
-         return u->toSI(list1[0].toDouble());
-   }
+   return Brewtarget::toDouble(amtUnit.cap(1), "Unit::valueFromString()");
 }
 
 // Return a
 QString Unit::convert(QString qstr, QString toUnit)
 {
+   QString fName;
+   double amt,si;
+   Unit *f, *u;
+
    if( ! Unit::isMapSetup )
       Unit::setupMap();
 
-   Unit* f;
-   double si = qstringToSI( qstr, &f, false );
-   Unit* u = getUnit(toUnit, false);
-   
+   fName = unitFromString(qstr);
+   amt = valueFromString(qstr);
+   f = getUnit(fName);
+
+   if ( f )
+      si = f->toSI(amt);
+   else
+      si = 0.0;
+
+   u = getUnit(toUnit, false);
+
+   // If we couldn't find either unit, or the two units don't match (eg, you
+   // cannot convert L to lb)
    if( u == 0 || f == 0 || u->getUnitType() != f->getUnitType() )
       return QString("%1 ?").arg(Brewtarget::displayAmount(si));
    else
       return QString("%1 %2").arg(Brewtarget::displayAmount(u->fromSI(si))).arg(toUnit);
 }
 
+// This mostly gets called when the unit entered in the field does not match
+// what the field has been set to. For example, if you displaying in Liters,
+// but enter "20 qt". Since the SIVolumeUnitSystem doesn't know what "qt" is,
+// we go searching for it.
+Unit* Unit::getUnit(QString& name, bool matchCurrentSystem)
+{
+   Unit* u;
+   Unit* defUnit = 0;
+
+
+   if( ! Unit::isMapSetup )
+      Unit::setupMap();
+
+   // Under most circumstances, there is a one-to-one relationship between
+   // unit string and Unit. C will only map to Unit::Celsius, for example. If
+   // there's only one match, just return it.
+   if ( nameToUnit.count(name) == 1 )
+      return nameToUnit.value(name);
+
+   // That solved something like 99% of the use cases. Now we have to handle
+   // those pesky volumes.
+   QMap<QString, Unit*>::iterator i = nameToUnit.find(name);
+
+   // Loop through the found Units, like Unit::us_quart and
+   // Unit::imperial_quart, and try to find one that matches the global
+   // default.
+   for( ; i != nameToUnit.end() && i.key() == name; ++i )
+   {
+      u = i.value();
+      if( u == 0 )
+         continue;
+
+      int system = u->getUnitOrTempSystem();
+
+      // Save this for later if we need it
+      if( system == USCustomary )
+         defUnit = u;
+
+      if( Brewtarget::thingToUnitSystem.value(Volume|system) == Brewtarget::thingToUnitSystem.value(Volume) )
+         return u;
+   }
+
+   // If we got here, we couldn't find a match. Unless something weird has
+   // happened, that means you entered "qt" into a field and the system
+   // default is SI. At that point, just use the USCustomary
+   return defUnit;
+}
+
 void Unit::setupMap()
 {
    Unit::nameToUnit.insert(Units::kilograms->getUnitName(), Units::kilograms);
@@ -224,6 +218,7 @@ void Unit::setupMap()
    Unit::nameToUnit.insert(Units::minutes->getUnitName(), Units::minutes);
    Unit::nameToUnit.insert(Units::hours->getUnitName(), Units::hours);
    Unit::nameToUnit.insert(Units::days->getUnitName(), Units::days);
+
    Unit::nameToUnit.insert(Units::celsius->getUnitName(), Units::celsius);
    Unit::nameToUnit.insert(Units::kelvin->getUnitName(), Units::kelvin);
    Unit::nameToUnit.insert(Units::fahrenheit->getUnitName(), Units::fahrenheit);
@@ -231,6 +226,9 @@ void Unit::setupMap()
    Unit::nameToUnit.insert(Units::srm->getUnitName(), Units::srm);
    Unit::nameToUnit.insert(Units::ebc->getUnitName(), Units::ebc);
 
+   Unit::nameToUnit.insert(Units::sp_grav->getUnitName(), Units::sp_grav);
+   Unit::nameToUnit.insert(Units::plato->getUnitName(), Units::plato);
+
    Unit::isMapSetup = true;
 }
 
@@ -239,6 +237,8 @@ KilogramUnit::KilogramUnit()
 {
    unitName = "kg";
    SIUnitName = "kg";
+   _type = Mass;
+   _unitSystem = SI;
 }
 
 double KilogramUnit::toSI( double amt ) const
@@ -256,6 +256,8 @@ GramUnit::GramUnit()
 {
    unitName = "g";
    SIUnitName = "kg";
+   _type = Mass;
+   _unitSystem = SI;
 }
 
 double GramUnit::toSI( double amt ) const
@@ -273,6 +275,8 @@ MilligramUnit::MilligramUnit()
 {
    unitName = "mg";
    SIUnitName = "kg";
+   _type = Mass;
+   _unitSystem = SI;
 }
 
 double MilligramUnit::toSI( double amt ) const
@@ -290,6 +294,8 @@ PoundUnit::PoundUnit()
 {
    unitName = "lb";
    SIUnitName = "kg";
+   _type = Mass;
+   _unitSystem = USCustomary;
 }
 
 double PoundUnit::toSI( double amt ) const
@@ -307,6 +313,8 @@ OunceUnit::OunceUnit()
 {
    unitName = "oz";
    SIUnitName = "kg";
+   _type = Mass;
+   _unitSystem = USCustomary;
 }
 
 double OunceUnit::toSI( double amt ) const
@@ -324,6 +332,8 @@ LiterUnit::LiterUnit()
 {
    unitName = "L";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = SI;
 }
 
 double LiterUnit::toSI( double amt ) const
@@ -341,6 +351,8 @@ MilliliterUnit::MilliliterUnit()
 {
    unitName = "mL";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = SI;
 }
 
 double MilliliterUnit::toSI( double amt ) const
@@ -359,6 +371,8 @@ USBarrelUnit::USBarrelUnit()
 {
    unitName = "bbl";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USBarrelUnit::toSI( double amt ) const
@@ -376,6 +390,8 @@ USGallonUnit::USGallonUnit()
 {
    unitName = "gal";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USGallonUnit::toSI( double amt ) const
@@ -393,6 +409,8 @@ USQuartUnit::USQuartUnit()
 {
    unitName = "qt";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USQuartUnit::toSI( double amt ) const
@@ -410,6 +428,8 @@ USCupUnit::USCupUnit()
 {
    unitName = "cup";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USCupUnit::toSI( double amt ) const
@@ -422,81 +442,13 @@ double USCupUnit::fromSI( double amt ) const
    return amt / 0.236588236;
 }
 
-// === Imperial Beer Barrel ===
-
-ImperialBarrelUnit::ImperialBarrelUnit()
-{
-   unitName = "bbl";
-   SIUnitName = "L";
-}
-
-double ImperialBarrelUnit::toSI( double amt ) const
-{
-   return amt * 163.659;
-}
-
-double ImperialBarrelUnit::fromSI( double amt ) const
-{
-   return amt / 163.659;
-}
-
-// === ImperialGallons ===
-ImperialGallonUnit::ImperialGallonUnit()
-{
-   unitName = "gal";
-   SIUnitName = "L";
-}
-
-double ImperialGallonUnit::toSI( double amt ) const
-{
-   return amt * 4.54609;
-}
-
-double ImperialGallonUnit::fromSI( double amt ) const
-{
-   return amt / 4.54609;
-}
-
-// === ImperialQuarts ===
-ImperialQuartUnit::ImperialQuartUnit()
-{
-   unitName = "qt";
-   SIUnitName = "L";
-}
-
-double ImperialQuartUnit::toSI( double amt ) const
-{
-   return amt * 1.1365225;
-}
-
-double ImperialQuartUnit::fromSI( double amt ) const
-{
-   return amt / 1.1365225;
-}
-
-// === ImperialCups ===
-ImperialCupUnit::ImperialCupUnit()
-{
-   unitName = "cup";
-   SIUnitName = "L";
-}
-
-double ImperialCupUnit::toSI( double amt ) const
-{
-   return amt * 0.284130625;
-}
-
-double ImperialCupUnit::fromSI( double amt ) const
-{
-   return amt / 0.284130625;
-}
-
-
 // === US Tablepoons ===
 USTablespoonUnit::USTablespoonUnit()
 {
    unitName = "tbsp";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USTablespoonUnit::toSI( double amt ) const
@@ -514,6 +466,8 @@ USTeaspoonUnit::USTeaspoonUnit()
 {
    unitName = "tsp";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = USCustomary;
 }
 
 double USTeaspoonUnit::toSI( double amt ) const
@@ -526,11 +480,91 @@ double USTeaspoonUnit::fromSI( double amt ) const
    return amt / 0.00492892159;
 }
 
+// === Imperial Beer Barrel ===
+
+ImperialBarrelUnit::ImperialBarrelUnit()
+{
+   unitName = "bbl";
+   SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
+}
+
+double ImperialBarrelUnit::toSI( double amt ) const
+{
+   return amt * 163.659;
+}
+
+double ImperialBarrelUnit::fromSI( double amt ) const
+{
+   return amt / 163.659;
+}
+
+// === ImperialGallons ===
+ImperialGallonUnit::ImperialGallonUnit()
+{
+   unitName = "gal";
+   SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
+}
+
+double ImperialGallonUnit::toSI( double amt ) const
+{
+   return amt * 4.54609;
+}
+
+double ImperialGallonUnit::fromSI( double amt ) const
+{
+   return amt / 4.54609;
+}
+
+// === ImperialQuarts ===
+ImperialQuartUnit::ImperialQuartUnit()
+{
+   unitName = "qt";
+   SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
+}
+
+double ImperialQuartUnit::toSI( double amt ) const
+{
+   return amt * 1.1365225;
+}
+
+double ImperialQuartUnit::fromSI( double amt ) const
+{
+   return amt / 1.1365225;
+}
+
+// === ImperialCups ===
+ImperialCupUnit::ImperialCupUnit()
+{
+   unitName = "cup";
+   SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
+}
+
+double ImperialCupUnit::toSI( double amt ) const
+{
+   return amt * 0.284130625;
+}
+
+double ImperialCupUnit::fromSI( double amt ) const
+{
+   return amt / 0.284130625;
+}
+
+
 // === Imperial Tablepoons ===
 ImperialTablespoonUnit::ImperialTablespoonUnit()
 {
    unitName = "tbsp";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
 }
 
 double ImperialTablespoonUnit::toSI( double amt ) const
@@ -548,6 +582,8 @@ ImperialTeaspoonUnit::ImperialTeaspoonUnit()
 {
    unitName = "tsp";
    SIUnitName = "L";
+   _type = Volume;
+   _unitSystem = Imperial;
 }
 
 double ImperialTeaspoonUnit::toSI( double amt ) const
@@ -564,7 +600,9 @@ double ImperialTeaspoonUnit::fromSI( double amt ) const
 SecondUnit::SecondUnit()
 {
    unitName = "s";
-   SIUnitName = "min"; // Pretend the SI unit is minutes for the sake of BeerXML.
+   SIUnitName = "min";
+   _type = Time;
+   _unitSystem = Any;
 }
 
 double SecondUnit::toSI( double amt ) const
@@ -581,7 +619,9 @@ double SecondUnit::fromSI( double amt ) const
 MinuteUnit::MinuteUnit()
 {
    unitName = "min";
-   SIUnitName = "min"; // Pretend the SI unit is minutes for the sake of BeerXML.
+   SIUnitName = "min";
+   _type = Time;
+   _unitSystem = Any;
 }
 
 double MinuteUnit::toSI( double amt ) const
@@ -598,7 +638,9 @@ double MinuteUnit::fromSI( double amt ) const
 HourUnit::HourUnit()
 {
    unitName = "hr";
-   SIUnitName = "min"; // Pretend the SI unit is minutes for the sake of BeerXML.
+   SIUnitName = "min";
+   _type = Time;
+   _unitSystem = Any;
 }
 
 double HourUnit::toSI( double amt ) const
@@ -615,7 +657,9 @@ double HourUnit::fromSI( double amt ) const
 DayUnit::DayUnit()
 {
    unitName = "day";
-   SIUnitName = "min"; // Pretend the SI unit is minutes for the sake of BeerXML.
+   SIUnitName = "min";
+   _type = Time;
+   _unitSystem = Any;
 }
 
 double DayUnit::toSI( double amt ) const
@@ -633,6 +677,8 @@ CelsiusUnit::CelsiusUnit()
 {
    unitName = "C";
    SIUnitName = "C";
+   _type = Temp;
+   _unitSystem = SI;
 }
 
 double CelsiusUnit::toSI( double amt ) const
@@ -645,11 +691,13 @@ double CelsiusUnit::fromSI( double amt ) const
    return amt;
 }
 
-// === Celsius ===
+// === Fahrenheit ===
 FahrenheitUnit::FahrenheitUnit()
 {
    unitName = "F";
    SIUnitName = "C";
+   _type = Temp;
+   _unitSystem = USCustomary;
 }
 
 double FahrenheitUnit::toSI( double amt ) const
@@ -667,6 +715,8 @@ KelvinUnit::KelvinUnit()
 {
    unitName = "K";
    SIUnitName = "K";
+   _type = Temp;
+   _unitSystem = SI;
 }
 
 double KelvinUnit::toSI( double amt ) const
@@ -684,6 +734,8 @@ SRMUnit::SRMUnit()
 {
    unitName = "srm";
    SIUnitName = "srm";
+   _type = Color;
+   _unitSystem = Any;
 }
 
 double SRMUnit::toSI( double amt ) const
@@ -701,6 +753,8 @@ EBCUnit::EBCUnit()
 {
    unitName = "ebc";
    SIUnitName = "srm";
+   _type = Color;
+   _unitSystem = Any;
 }
 
 double EBCUnit::toSI( double amt ) const
@@ -712,3 +766,35 @@ double EBCUnit::fromSI( double amt ) const
 {
    return amt * 25.0/12.7;
 }
+
+// === Density ===
+SgUnit::SgUnit()
+{
+   unitName   = "sg";
+   SIUnitName = "sg";
+   _type = Density;
+   _unitSystem = Any;
+}
+
+double SgUnit::toSI( double amt ) const { return amt; }
+
+double SgUnit::fromSI( double amt ) const { return amt; }
+
+PlatoUnit::PlatoUnit()
+{
+   unitName = "P";
+   SIUnitName = "sg";
+   _type = Density;
+   _unitSystem = Any;
+}
+
+double PlatoUnit::toSI( double amt ) const
+{
+   return Algorithms::PlatoToSG_20C20C( amt );
+}
+
+double PlatoUnit::fromSI(double amt) const
+{
+   return Algorithms::SG_20C20C_toPlato(amt);
+}
+
