@@ -1,17 +1,18 @@
 /*
- * water.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * water.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -126,52 +127,14 @@ void Water::setNotes( const QString &var )
 }
 
 //=========================="GET" METHODS=======================================
-QString Water::name() const
-{
-   return get("name").toString();
-}
+QString Water::name() const { return get("name").toString(); }
+QString Water::notes() const { return get("notes").toString(); }
 
-double Water::sulfate_ppm() const
-{
-   return get("sulfate").toDouble();
-}
-
-double Water::amount_l() const
-{
-   return get("amount").toDouble();
-}
-
-double Water::calcium_ppm() const
-{
-   return get("calcium").toDouble();
-}
-
-double Water::bicarbonate_ppm() const
-{
-   return get("bicarbonate").toDouble();
-}
-
-double Water::chloride_ppm() const
-{
-   return get("chloride").toDouble();
-}
-
-double Water::sodium_ppm() const
-{
-   return get("sodium").toDouble();
-}
-
-double Water::magnesium_ppm() const
-{
-   return get("magnesium").toDouble();
-}
-
-double Water::ph() const
-{
-   return get("ph").toDouble();
-}
-
-QString Water::notes() const
-{
-   return get("notes").toString();
-}
+double Water::sulfate_ppm() const { return get("sulfate").toDouble(); }
+double Water::amount_l() const { return get("amount").toDouble(); }
+double Water::calcium_ppm() const { return get("calcium").toDouble(); }
+double Water::bicarbonate_ppm() const { return get("bicarbonate").toDouble(); }
+double Water::chloride_ppm() const { return get("chloride").toDouble(); }
+double Water::sodium_ppm() const { return get("sodium").toDouble(); }
+double Water::magnesium_ppm() const { return get("magnesium").toDouble(); }
+double Water::ph() const { return get("ph").toDouble(); }
