@@ -1,17 +1,21 @@
 /*
- * yeast.cpp is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * yeast.cpp is part of Brewtarget, and is Copyright the following
+ * authors 2009-2014
+ * - marker5a
+ * - Philip Greggory Lee <rocketman768@gmail.com>
+ * - plut0nium
+ * - Samuel Östling <MrOstling@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,6 +39,7 @@ QHash<QString,QString> Yeast::tagToPropHash()
    //propHash["TYPE"] = "type";
    //propHash["FORM"] = "form";
    propHash["AMOUNT"] = "amount";
+   propHash["INVENTORY"] = "inventory";
    propHash["AMOUNT_IS_WEIGHT"] = "amountIsWeight";
    propHash["LABORATORY"] = "laboratory";
    propHash["PRODUCT_ID"] = "productID";
@@ -71,21 +76,31 @@ Yeast::Yeast(Yeast const& other) : BeerXMLElement(other)
 }
 
 //============================="GET" METHODS====================================
-QString Yeast::name() const
-{
-   return get("name").toString();
-}
+QString Yeast::name() const { return get("name").toString(); }
+QString Yeast::laboratory() const { return get("laboratory").toString();; }
+QString Yeast::productID() const { return get("product_id").toString(); }
+QString Yeast::notes() const { return get("notes").toString(); }
+QString Yeast::bestFor() const { return get("best_for").toString(); }
 
-Yeast::Type Yeast::type() const
-{
-   return static_cast<Yeast::Type>( types.indexOf(get("ytype").toString()));
-}
+const QString Yeast::typeString() const { return types.at(type()); }
+const QString Yeast::formString() const { return forms.at(form()); }
+const QString Yeast::flocculationString() const { return flocculations.at(flocculation()); }
 
-const QString Yeast::typeString() const
-{
-   return types.at(type());
-}
+double Yeast::amount() const { return get("amount").toDouble(); }
+double Yeast::minTemperature_c() const { return get("min_temperature").toDouble(); }
+double Yeast::maxTemperature_c() const { return get("max_temperature").toDouble(); }
+double Yeast::attenuation_pct() const { return get("attenuation").toDouble(); }
 
+int Yeast::inventory() const { return getInventory("quanta").toInt(); }
+int Yeast::timesCultured() const { return get("times_cultured").toInt(); }
+int Yeast::maxReuse() const { return get("max_reuse").toInt(); }
+
+bool Yeast::addToSecondary() const { return get("add_to_secondary").toBool(); }
+bool Yeast::amountIsWeight() const { return get("amount_is_weight").toBool(); }
+
+Yeast::Form Yeast::form() const { return static_cast<Yeast::Form>( forms.indexOf(get("form").toString())); }
+Yeast::Flocculation Yeast::flocculation() const { return static_cast<Yeast::Flocculation>( flocculations.indexOf(get("flocculation").toString())); }
+Yeast::Type Yeast::type() const { return static_cast<Yeast::Type>( types.indexOf(get("ytype").toString())); }
 const QString Yeast::typeStringTr() const
 {
    static QStringList typesTr = QStringList() << QObject::tr("Ale")
@@ -96,16 +111,6 @@ const QString Yeast::typeStringTr() const
    return typesTr.at(type());
 }
 
-Yeast::Form Yeast::form() const
-{
-   return static_cast<Yeast::Form>( forms.indexOf(get("form").toString()));
-}
-
-const QString Yeast::formString() const
-{
-   return forms.at(form());
-}
-
 const QString Yeast::formStringTr() const
 {
    static QStringList formsTr = QStringList() << QObject::tr("Liquid")
@@ -115,46 +120,6 @@ const QString Yeast::formStringTr() const
    return formsTr.at(form());
 }
 
-double Yeast::amount() const
-{
-   return get("amount").toDouble();
-}
-
-bool Yeast::amountIsWeight() const
-{
-   return get("amount_is_weight").toBool();
-}
-
-QString Yeast::laboratory() const
-{
-   return get("laboratory").toString();;
-}
-
-QString Yeast::productID() const
-{
-   return get("product_id").toString();
-}
-
-double Yeast::minTemperature_c() const
-{
-   return get("min_temperature").toDouble();
-}
-
-double Yeast::maxTemperature_c() const
-{
-   return get("max_temperature").toDouble();
-}
-
-Yeast::Flocculation Yeast::flocculation() const
-{
-   return static_cast<Yeast::Flocculation>( flocculations.indexOf(get("flocculation").toString()));
-}
-
-const QString Yeast::flocculationString() const
-{
-   return flocculations.at(flocculation());
-}
-
 const QString Yeast::flocculationStringTr() const
 {
    static QStringList flocculationsTr = QStringList() << QObject::tr("Low")
@@ -164,36 +129,6 @@ const QString Yeast::flocculationStringTr() const
    return flocculationsTr.at(flocculation());
 }
 
-double Yeast::attenuation_pct() const
-{
-   return get("attenuation").toDouble();
-}
-
-QString Yeast::notes() const
-{
-   return get("notes").toString();
-}
-
-QString Yeast::bestFor() const
-{
-   return get("best_for").toString();
-}
-
-int Yeast::timesCultured() const
-{
-   return get("times_cultured").toInt();
-}
-
-int Yeast::maxReuse() const
-{
-   return get("max_reuse").toInt();
-}
-
-bool Yeast::addToSecondary() const
-{
-   return get("add_to_secondary").toBool();
-}
-
 //============================="SET" METHODS====================================
 void Yeast::setName( const QString& var )
 {
@@ -219,6 +154,14 @@ void Yeast::setAmount( double var )
       set("amount", "amount", var);
 }
 
+void Yeast::setInventoryQuanta( int var )
+{
+   if( var < 0.0 )
+      Brewtarget::logW( QString("Yeast: inventory < 0: %1").arg(var) );
+   else
+      setInventory("inventory", "quanta", var);
+}
+
 void Yeast::setAmountIsWeight( bool var )
 {
    set("amountIsWeight", "amount_is_weight", var);
